@@ -5,9 +5,11 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Button, Checkbox, Divider } from '@material-ui/core';
 import * as React from 'react'
-import { Global } from '../Global';
+import { DIV, Global } from '../Global';
+
+import { Button, Checkbox, Divider } from '@mui/material';
+
 import { ServerConnection } from '@jupyterlab/services';
 
 interface IProps {
@@ -71,15 +73,15 @@ export class Agreement extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
-                <div className='jp-optumi-logo'/>
-                <div style={{
+                <DIV className='jp-optumi-logo'/>
+                <DIV sx={{
                     display: 'flex',
                     flexFlow: 'column',
                     overflow: 'hidden',
                     height: '100%',
                 }}>
-                    <div
-                        style={{
+                    <DIV
+                        sx={{
                             padding: '0px',
                             flexGrow: 1,
                             // overflowY: 'auto',
@@ -89,21 +91,21 @@ export class Agreement extends React.Component<IProps, IState> {
                         }}
                     >
                         <embed  src={Global.agreementURL} height='100%' width='100%' />
-                    </div>
+                    </DIV>
                     <Divider variant='middle' />
-                    <div style={{padding: '6px', display: 'flex', justifyContent: 'center'}}>
+                    <DIV sx={{padding: '6px', display: 'flex', justifyContent: 'center'}}>
                         <Checkbox
                             checked={this.state.agreed}
                             color='primary'
                             onClick={() => this.safeSetState({ agreed: !this.state.agreed})}
-                            style={{
+                            sx={{
                                 padding: '6px',
                                 margin: '0px',
                                 flexGrow: 1,
                             }}
                         />
-                        <div 
-                            style={{
+                        <DIV 
+                            sx={{
                                 padding: '6px',
                                 margin: '0px',
                                 flexGrow: 1,
@@ -111,12 +113,12 @@ export class Agreement extends React.Component<IProps, IState> {
                             }}
                         >
                             I have read and I agree to the Optumi Terms and Conditions of Service
-                        </div>
-                    </div>
-                    <div style={{padding: '6px', display: 'flex', justifyContent: 'center'}}>
+                        </DIV>
+                    </DIV>
+                    <DIV sx={{padding: '6px', display: 'flex', justifyContent: 'center'}}>
                         <Button
                             onClick={this.logout}
-                            style={{
+                            sx={{
                                 padding: '9px',
                                 fontWeight: 'bold',
                                 fontSize: '14px',
@@ -132,7 +134,7 @@ export class Agreement extends React.Component<IProps, IState> {
                             color='primary'
                             variant='contained'
                             disabled={!this.state.agreed}
-                            style={{
+                            sx={{
                                 padding: '9px',
                                 fontWeight: 'bold',
                                 fontSize: '14px',
@@ -143,8 +145,8 @@ export class Agreement extends React.Component<IProps, IState> {
                         >
                             I accept
                         </Button>
-                    </div>
-                </div>
+                    </DIV>
+                </DIV>
             </>
         )
     }
