@@ -6,36 +6,17 @@
 **/
 
 import * as React from 'react'
-import { Global } from '../Global';
+import { DIV, Global, SPAN } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Chip, darken, IconButton, lighten } from '@mui/material';
+import { withStyles } from '@mui/styles';
+import { Close, KeyboardArrowDown, KeyboardArrowUp } from '@mui/icons-material';
 
-import { Chip, darken, IconButton, lighten, Theme, withStyles, withTheme } from '@material-ui/core';
 import { Popper } from '../core/Popper';
-import { Close, KeyboardArrowDown, KeyboardArrowUp } from '@material-ui/icons';
-import { CSSProperties } from '@material-ui/styles';
-
-const StyledChip = withStyles(theme => ({
-    root: {
-        height: '20px',
-        fontSize: '12px',
-        // borderWidth: '2px',
-        // borderStyle: 'solid',
-        transition: 'all 300ms cubic-bezier(0.4, 0, 0.2, 1) 0ms',
-        transitionProperty: 'background-color',
-    },
-    icon: {
-        position: 'absolute',
-        right: theme.spacing(0.75),
-    },
-    label: {
-        position: 'absolute',
-        left: theme.spacing(0.5),
-        padding: theme.spacing(0),
-    },
-}))(Chip)
 
 interface IProps {
-    style: CSSProperties
-    theme: Theme
+    sx: SxProps<Theme>
     title: string
     color: string
     clearValue: () => any
@@ -48,21 +29,50 @@ interface IState {
     open: boolean
 }
 
-class ChipPopper extends React.Component<IProps, IState> {
+export class ChipPopper extends React.Component<IProps, IState> {
     _isMounted = false;
     close: () => void = () => {}
     stopPropagation: () => void = () => {}
 
+    private StyledChip: any
+
     public constructor(props: IProps) {
         super(props)
         this.state = {
             open: false,
         }
+        this.StyledChip = withStyles(theme => ({
+            root: {
+                height: '20px',
+                fontSize: '12px',
+                // borderWidth: '2px',
+                // borderStyle: 'solid',
+                transition: 'all 300ms cubic-bezier(0.4, 0, 0.2, 1) 0ms',
+                transitionProperty: 'background-color',
+                '&:active': {
+                    boxShadow: 'none',
+                }
+            },
+            icon: {
+                position: 'absolute',
+                right: theme.spacing(0.75),
+            },
+            label: {
+                position: 'absolute',
+                left: theme.spacing(0.5),
+                padding: theme.spacing(0),
+            },
+            clickable: {
+                '&:hover': {
+                    filter: 'brightness(0.95)',
+                    transition: 'filter 250ms cubic-bezier(0.4, 0, 0.2, 1) 0ms'
+                },
+            },
+        }))(Chip)
     }
 
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        const theme: Theme = this.props.theme
         const description = this.props.getHeaderDescription();
         const modified: boolean = description != 'Any';
 		return (
@@ -73,23 +83,26 @@ class ChipPopper extends React.Component<IProps, IState> {
                 close={(close: () => void) => this.close = close}
                 stopPropagation={(stopPropagation: () => void) => this.stopPropagation = stopPropagation}
                 button={
-                    <StyledChip
+                    <this.StyledChip
                         key={this.props.title + 'chip'}
-                        clickable
-                        style={Object.assign({
+                        sx={Object.assign({
                             fontWeight: modified ? 'bold' : undefined,
                             color: modified ? this.props.color : undefined,
                             border: modified ? ('0px solid ' + this.props.color) : undefined,
-                            backgroundColor: modified ? Global.themeManager.isLight(Global.themeManager.theme) ? lighten(this.props.color, 0.8): darken(this.props.color, 0.65) : 'var(--jp-layout-color1)'
-                        }, this.props.style)}
+                            backgroundColor: (modified ? Global.themeManager.isLight(Global.themeManager.theme) ? lighten(this.props.color, 0.8) : darken(this.props.color, 0.65) : 'var(--jp-layout-color1)') + ' !important'
+                        }, this.props.sx)}
                         variant='outlined'
                         label={this.props.getChipDescription ? this.props.getChipDescription() : this.props.title + ': ' + this.props.getHeaderDescription()}
                         icon={(
                             modified ? (
                                 <IconButton
-                                    style={{
-                                        padding: theme.spacing(0.25),
-                                        margin: theme.spacing(-0.25, -0.75, -0.25, -0.25),
+                                    size='large'
+                                    sx={{
+                                        padding: 0.25,
+                                        marginTop: -0.25,
+                                        marginRight: -0.75,
+                                        marginBottom: -0.25,
+                                        marginLeft: -0.25,
                                         zIndex: 1,
                                     }}
                                     onClick={() => {
@@ -97,46 +110,47 @@ class ChipPopper extends React.Component<IProps, IState> {
                                         this.stopPropagation()
                                     }}
                                 >
-                                    <Close style={{height: '14px',width: '14px', color: this.props.color}}/>
+                                    <Close sx={{height: '14px',width: '14px', color: this.props.color}}/>
                                 </IconButton>
                             ) : this.state.open ? (
-                                <KeyboardArrowUp style={{height: '14px',width: '14px'}}/>
+                                <KeyboardArrowUp sx={{height: '14px',width: '14px'}}/>
                             ) : (
-                                <KeyboardArrowDown style={{height: '14px',width: '14px'}}/>
+                                <KeyboardArrowDown sx={{height: '14px',width: '14px'}}/>
                             )
                         )}
                     />
                 }
                 popup={
-                    <div style={{
+                    <DIV sx={{
                         display: 'flex',
                         flexDirection: 'column',
-                        margin: theme.spacing(1),
+                        margin: 1,
                         fontSize: '15px',
                         lineHeight: '15px',
                     }}>
-                        <div style={{display: 'flex'}}>
-                            <span style={{fontWeight: 'bold'}}>
+                        <DIV sx={{display: 'flex'}}>
+                            <SPAN sx={{fontWeight: 'bold'}}>
                                 {this.props.title}:
-                            </span>
-                            <span style={{whiteSpace: 'pre'}}>
+                            </SPAN>
+                            <SPAN sx={{whiteSpace: 'pre'}}>
                                 {` ${description}`}
-                            </span>
-                            <div style={{width: '100%'}} />
+                            </SPAN>
+                            <DIV sx={{width: '100%'}} />
                             <IconButton
-                                style={{padding: theme.spacing(0.5), margin: theme.spacing(-0.5)}}
+                                size='large'
+                                sx={{padding: 0.5, margin: -0.5}}
                                 onClick={this.close}
                             >
-                                <Close style={{width: '15px', height: '15px'}}/>
+                                <Close sx={{width: '15px', height: '15px'}}/>
                             </IconButton>
-                        </div>
-                        <div style={{fontSize: '14px'}}>
+                        </DIV>
+                        <DIV sx={{fontSize: '14px'}}>
                             {this.props.popperContent}
-                        </div>
-                    </div>
+                        </DIV>
+                    </DIV>
                 }
             />
-		);
+        );
 	}
 
     private handleThemeChange = () => this.forceUpdate()
@@ -187,5 +201,3 @@ class ChipPopper extends React.Component<IProps, IState> {
         }
     }
 }
-const ThemedChipPopper = withTheme(ChipPopper)
-export {ThemedChipPopper as ChipPopper}
