@@ -6,26 +6,26 @@
 **/
 
 import * as React from 'react'
-import { Global } from '../Global';
-import { TreeView, TreeItem } from '@material-ui/lab'
-import { ChevronRight, ExpandMore } from '@material-ui/icons';
-import { withStyles } from '@material-ui/core';
+import { DIV, Global, SPAN } from '../Global';
+
+import { TreeView, TreeItem } from '@mui/lab'
+import { withStyles } from '@mui/styles';
+import { ChevronRight, ExpandMore } from '@mui/icons-material';
+
 import FileExtensionIcon from './FileExtensionIcon';
+import { FileMetadata } from './deploy/fileBrowser/FileBrowser';
+import moment from 'moment';
 
-type TreeNode<FileMetadata> = DirectoryNode<FileMetadata> | FileNode<FileMetadata>
+type TreeNode = DirectoryNode | FileNode
 
-interface MinimumFileMetadata {
-    path: string
-}
-
-interface DirectoryNode<FileMetadata> {
+interface DirectoryNode {
     path: string
     file: string
-    children: TreeNode<FileMetadata>[]
+    children: TreeNode[]
     metadata: undefined
 }
 
-interface FileNode<FileMetadata> {
+interface FileNode {
     path: string
     file: string
     metadata: FileMetadata
@@ -38,7 +38,7 @@ interface HidableIcon {
     height: number
 }
 
-interface IProps<FileMetadata> {
+interface IProps {
     files: FileMetadata[]
     fileHidableIcon?: (file: FileMetadata) => HidableIcon
     directoryHidableIcon?: (path: string) => HidableIcon
@@ -50,9 +50,9 @@ interface IState {
     expanded: string[]
 }
 
-export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Component<IProps<FileMetadata>, IState> {
+export class FileTree extends React.Component<IProps, IState> {
 
-    constructor(props: IProps<FileMetadata>) {
+    constructor(props: IProps) {
         super(props);
         
         this.state = {
@@ -62,22 +62,23 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
 
     private renderTreeItems = (files: FileMetadata[]): JSX.Element[] | undefined => {
 
-        const generateTreeStructure = (): TreeNode<FileMetadata> => {
+        const generateTreeStructure = (): TreeNode => {
 
-            const generatePathStructure = (metadata: FileMetadata, path: string, file: string): TreeNode<FileMetadata> => {
+            const generatePathStructure = (metadata: FileMetadata, path: string, file: string): TreeNode => {
+                if (file.startsWith('~/')) file = file.replace('~/', '')
                 let parts = file.split(/(?<=^\/?[^\/]+)(?=\/)/)
                 if (parts.length > 1) {
                     return {
                         path: path,
                         file: parts[0],
                         children: [generatePathStructure(metadata, path + parts[0], parts[1])]
-                    } as DirectoryNode<FileMetadata>
+                    } as DirectoryNode
                 } else {
-                    return {path, file, metadata} as FileNode<FileMetadata>
+                    return {path, file, metadata} as FileNode
                 }
             }
 
-            const mergePathStructure = (treeStructure: TreeNode<FileMetadata>, pathStructure: TreeNode<FileMetadata>): TreeNode<FileMetadata> => {
+            const mergePathStructure = (treeStructure: TreeNode, pathStructure: TreeNode): TreeNode => {
                 if (treeStructure.children === undefined) {
                     treeStructure.children = [pathStructure]
                     return treeStructure
@@ -97,7 +98,7 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
                 }
             }
 
-            let treeStructure: TreeNode<FileMetadata> = {path: '', file: '', children: []} as DirectoryNode<FileMetadata>
+            let treeStructure: TreeNode = {path: '', file: '', children: []} as DirectoryNode
             for (let file of files) {
                 let pathStructure = generatePathStructure(file, '', file.path)
                 treeStructure = mergePathStructure(treeStructure, pathStructure)
@@ -105,7 +106,7 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
             return treeStructure
         }
 
-        const collapseTreeStructure = (structure: TreeNode<FileMetadata>): TreeNode<FileMetadata> => {
+        const collapseTreeStructure = (structure: TreeNode): TreeNode => {
             if (structure.children === undefined) {
                 return structure                
             } else if (structure.children.length === 1) {
@@ -122,10 +123,10 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
             }
         }
 
-        const renderTreeStructure = (structure: TreeNode<FileMetadata>, includeSlash: boolean): JSX.Element => {
+        const renderTreeStructure = (structure: TreeNode, includeSlash: boolean): JSX.Element => {
             let hasChildren = Array.isArray(structure.children)
             let cappedMessage
-            const maxChildren = 50
+            const maxChildren = 250
             if (hasChildren && structure.children.length > maxChildren) {
                 cappedMessage = (
                     <TreeItem
@@ -133,7 +134,7 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
                         key={structure.path + structure.file + 'toomany'}
                         nodeId={structure.path + structure.file + 'toomany'}
                         label={(
-                            <div style={{
+                            <DIV sx={{
                                 flexGrow: 1,
                                 fontSize: 'var(--jp-ui-font-size1)',
                                 fontFamily: 'var(--jp-ui-font-family)',
@@ -142,7 +143,7 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
                                 textOverflow: 'ellipsis',
                             }}>
                                 Too many files, hiding remaining {structure.children.length - maxChildren}
-                            </div>
+                            </DIV>
                         )}
                     />
                 )
@@ -164,7 +165,7 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
                 >
                     {hasChildren ? (
                         <>
-                            {structure.children.splice(0, maxChildren).map((child: TreeNode<FileMetadata>) => renderTreeStructure(child, false))}
+                            {structure.children.splice(0, maxChildren).map((child: TreeNode) => renderTreeStructure(child, false))}
                             {cappedMessage}
                         </>
                     ) : undefined}
@@ -172,9 +173,9 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
             )
         }
 
-        let structure: TreeNode<FileMetadata> = generateTreeStructure()
+        let structure: TreeNode = generateTreeStructure()
         return Array.isArray(structure.children) ? (
-            structure.children.map((child: TreeNode<FileMetadata>) => renderTreeStructure(collapseTreeStructure(child), true))
+            structure.children.map((child: TreeNode) => renderTreeStructure(collapseTreeStructure(child), true))
         ) : undefined
     }
 
@@ -195,7 +196,7 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
         )
     }
 
-    public shouldComponentUpdate = (nextProps: IProps<FileMetadata>, nextState: IState): boolean => {
+    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -207,8 +208,8 @@ export class FileTree<FileMetadata extends MinimumFileMetadata> extends React.Co
     }
 }
 
-interface ItemProps<FileMetadata> {
-    structure: TreeNode<FileMetadata>
+interface ItemProps {
+    structure: TreeNode
     includeSlash: boolean
     title?: string
     hidableIcon?: HidableIcon
@@ -219,11 +220,11 @@ interface ItemState {
     hovered: boolean
 }
 
-export class FileTreeItem<FileMetadata extends MinimumFileMetadata> extends React.Component<ItemProps<FileMetadata>, ItemState> {
+export class FileTreeItem extends React.Component<ItemProps, ItemState> {
     private _isMounted = false
     private StyledTreeItem: any
 
-    constructor(props: ItemProps<FileMetadata>) {
+    constructor(props: ItemProps) {
         super(props)
 
         this.StyledTreeItem = withStyles({
@@ -254,21 +255,21 @@ export class FileTreeItem<FileMetadata extends MinimumFileMetadata> extends Reac
         const structure = this.props.structure
         const hidableIcon = this.props.hidableIcon
         return (
-            <div
+            <DIV
                 key={structure.path + structure.file}
                 className={this.state.hovered ? 'hovered' : undefined}
-                style={{display: 'flex', width: '100%', position: 'relative'}}
+                sx={{display: 'flex', width: '100%', position: 'relative'}}
             >
                 {hidableIcon && (
-                    <div
-                        style={{position: 'absolute', right: '0px'}}
+                    <DIV
+                        sx={{position: 'absolute', right: '0px'}}
                         onMouseOver={() => this.safeSetState({hovered: true})}
                         onMouseOut={() => this.safeSetState({hovered: false})}
                     >
-                        <div style={{display: 'inline-flex', position: 'absolute', right: '0px'}}>
+                        <DIV sx={{display: 'inline-flex', position: 'absolute', right: '0px'}}>
                             {hidableIcon.icon}
-                        </div>
-                        <div style={{
+                        </DIV>
+                        <DIV sx={{
                             position: 'absolute',
                             right: this.state.hovered ? hidableIcon.width + 'px' : '0px',
                             width: this.state.hovered ? '0px' : hidableIcon.width + 'px',
@@ -276,17 +277,17 @@ export class FileTreeItem<FileMetadata extends MinimumFileMetadata> extends Reac
                             backgroundColor: 'var(--jp-layout-color1)',
                             transitionDuration: '300ms',
                         }} />
-                    </div>
+                    </DIV>
                 )}
                 <this.StyledTreeItem
                     nodeId={structure.path + structure.file}
                     endIcon={<FileExtensionIcon path={structure.file}/>}
                     label={(
-                        <div
+                        <DIV
                             onMouseOver={() => this.safeSetState({hovered: true})}
                             onMouseOut={() => this.safeSetState({hovered: false})}
                             title={this.props.title}
-                            style={{
+                            sx={{
                                 flexGrow: 1,
                                 fontSize: 'var(--jp-ui-font-size1)',
                                 fontFamily: 'var(--jp-ui-font-family)',
@@ -298,13 +299,14 @@ export class FileTreeItem<FileMetadata extends MinimumFileMetadata> extends Reac
                             }}
                         >
                             {structure.file.replace(this.props.includeSlash ? '' : /^\//, '') /*+ (hasChildren ? '/' : '')*/}
-                        </div>
+                            {structure.metadata && (<SPAN sx={{marginLeft: '6px', opacity: '0.5'}}>{moment(structure.metadata.last_modified).format('YYYY-MM-DD hh:mm:ss')}</SPAN>)}
+                        </DIV>
                     )}
                 >
                     {this.props.children}
                 </this.StyledTreeItem>
-            </div>
-        )
+            </DIV>
+        );
     }
     
     public componentDidMount = () => {
@@ -337,7 +339,7 @@ export class FileTreeItem<FileMetadata extends MinimumFileMetadata> extends Reac
 		}
 	}
 
-    public shouldComponentUpdate = (nextProps: ItemProps<FileMetadata>, nextState: ItemState): boolean => {
+    public shouldComponentUpdate = (nextProps: ItemProps, nextState: ItemState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
