@@ -5,20 +5,22 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Button, Dialog, DialogContent, IconButton, Tab, Tabs, withStyles } from '@material-ui/core';
 import * as React from 'react';
-import DialogTitle from '@material-ui/core/DialogTitle';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import CloseIcon from '@material-ui/icons/Close';
-import { Global } from '../Global';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Button, Dialog, DialogContent, DialogTitle, IconButton, Tab, Tabs } from '@mui/material';
+import { withStyles } from '@mui/styles';
+import { Close as CloseIcon, /*OpenInNew as OpenInNewIcon*/ } from '@mui/icons-material';
+
 import { ServerConnection } from '@jupyterlab/services';
-import { AccountConnectorsSubMenu, AccountFilesSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountPaymentSubMenu } from './settings/SettingsMenu';
+
+import { AccountConnectorsSubMenu, AccountFilesSubMenu, AccountPreferencesSubMenu, AccountLimitsSubMenu, AccountBillingSubMenu } from './settings/SettingsMenu';
 import { ShadowedDivider } from '../core';
 import { User } from '../models/User';
 import WarningPopup from '../core/WarningPopup';
 import { App } from '../models/application/App';
-
-import OpenInNewIcon from '@material-ui/icons/OpenInNew';
+import { Colors } from '../Colors';
 
 const StyledDialog = withStyles({
     paper: {
@@ -26,7 +28,6 @@ const StyledDialog = withStyles({
         // width: '100%',
         height: '80%',
         overflowY: 'visible',
-        backgroundColor: 'var(--jp-layout-color1)',
         maxWidth: 'inherit',
     },
 })(Dialog);
@@ -34,16 +35,21 @@ const StyledDialog = withStyles({
 export const enum Page {
     PREFERENCES = 0,
     LIMITS = 1,
-    PAYMENT = 2,
+    FILES = 2,
     CONNECTORS = 3,
-    FILES = 4,
+    BILLING = 4,
 }
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     onOpen?: () => void
 	onClose?: () => void
     getOpenTo?: (openTo: (page: Page) => Promise<void>) => void // This is somewhat spaghetti code-y, maybe think about revising
+    balance: number
+    machineCost: number
+    serviceFeeCost: number
+    storageCost: number
+    egressCost: number
 }
 
 interface IState {
@@ -114,22 +120,23 @@ export class UserDialog extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var defaultProfilePicture: string = Global.user.name.replace(/(?<=\B)\w+/g, '').replace(/[ ]/g, '').toUpperCase()
         return (
-            <div style={Object.assign({}, this.props.style)} >
+            <DIV sx={Object.assign({}, this.props.sx)} >
                 <IconButton
+                    size='large'
                     onClick={this.handleClickOpen}
-                    style={{
+                    sx={{
                         display: 'inline-block',
                         width: '36px',
                         height: '36px',
-                        padding: '3px',
+                        padding: '6px',
                     }}
                 >
-                    <div style={{
+                    <DIV sx={{
                         width: '24px',
                         height: '24px',
                         // margin: '6px auto',
                         borderRadius: '12px',
-                        backgroundColor: '#10A0F9',
+                        backgroundColor: Colors.PRIMARY,
                         color: 'white',
                         fontSize: '14px',
                         fontWeight: 'bold',
@@ -137,7 +144,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                         textAlign: 'center'
                     }}>
                         {defaultProfilePicture[defaultProfilePicture.length-1]}
-                    </div>
+                    </DIV>
                 </IconButton>
                 <StyledDialog
 					open={this.state.open}
@@ -150,29 +157,24 @@ export class UserDialog extends React.Component<IProps, IState> {
                     }}
                     scroll='paper'
 				>
-					<DialogTitle
-					    disableTypography
-                        style={{
-                            display: 'inline-flex',
-                            backgroundColor: 'var(--jp-layout-color2)',
-                            height: '60px',
-                            padding: '6px',
-                            borderRadius: '4px',
-                        }}
-                    >
-                        <div style={{
+					<DialogTitle sx={{
+                        display: 'inline-flex',
+                        height: '60px',
+                        padding: '6px',
+                    }}>
+                        <DIV sx={{
                             display: 'inline-flex',
                             minWidth: '150px',
                             fontSize: '16px',
                             fontWeight: 'bold',
                             paddingRight: '12px', // this is 6px counteracting the DialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
-                            <div style={{margin: 'auto', paddingLeft: '12px'}}>
+                            <DIV sx={{margin: 'auto', paddingLeft: '12px'}}>
             					Settings
-                            </div>
-                        </div>
-                        <div style={{flexGrow: 1}} />
-                        <div>
+                            </DIV>
+                        </DIV>
+                        <DIV sx={{flexGrow: 1}} />
+                        <DIV>
                             <WarningPopup
                                 open={this.state.showLogoutWithSessionPopup}
                                 headerText="Are you sure?"
@@ -198,17 +200,17 @@ export class UserDialog extends React.Component<IProps, IState> {
                             <Button 
                                 onClick={() => window.open('https://login.optumi.com/enduser/settings?iframe=true&iframeControlHideAll=true', '_blank')}
                                 disableElevation
-                                style={{ height: '36px', margin: '6px' }}
-                                variant="contained"
+                                sx={{ height: '36px', margin: '6px' }}
+                                variant="outlined"
                                 color="primary"
-                                endIcon={<OpenInNewIcon/>}
+                                // endIcon={<OpenInNewIcon/>}
                             >
-                                Account
+                                Edit profile
                             </Button>
                             <Button
                                 disableElevation
-                                style={{ height: '36px', margin: '6px' }}
-                                variant="contained"
+                                sx={{ height: '36px', margin: '6px' }}
+                                variant="outlined"
                                 color="primary"
                                 onClick={() => {
                                     const user: User = Global.user;
@@ -221,8 +223,8 @@ export class UserDialog extends React.Component<IProps, IState> {
                             >
                                 Logout
                             </Button>
-                        </div>
-                        <div>
+                        </DIV>
+                        <DIV>
                             <WarningPopup
                                 open={this.state.showCloseWithInvalidNumberPopup}
                                 headerText="Heads Up!"
@@ -243,6 +245,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 }}
                             />
                             <IconButton
+                                size='large'
                                 onClick={() => {
                                     if (!this.state.validPhoneNumber) {
                                         this.safeSetState({ showCloseWithInvalidNumberPopup: true });
@@ -250,7 +253,7 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         this.handleClose();
                                     }
                                 }}
-                                style={{
+                                sx={{
                                     margin: '6px',
                                     display: 'inline-block',
                                     width: '36px',
@@ -259,24 +262,24 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 }}
                             >
                                 <CloseIcon
-                                    style={{
+                                    sx={{
                                         width: '30px',
                                         height: '30px',
                                         padding: '3px',
                                     }}
                                 />
                             </IconButton>
-                        </div>
+                        </DIV>
 					</DialogTitle>
                     <ShadowedDivider />
-                    <div style={{display: 'flex', height: 'calc(100% - 60px - 2px'}}>
-                        <div style={{width: '150px'}}>
-                            <DialogContent style={{
+                    <DIV sx={{display: 'flex', height: 'calc(100% - 60px - 2px)'}}>
+                        <DIV sx={{width: '150px'}}>
+                            <DialogContent sx={{
                                 overflowY: 'auto',
                                 height: '100%',
                                 padding: '0px',
                             }}>
-                                <div style={{
+                                <DIV sx={{
 									display: 'flex',
 									flexDirection: 'column',
 									padding: '6px',
@@ -289,11 +292,12 @@ export class UserDialog extends React.Component<IProps, IState> {
                                         variant='fullWidth'
                                         indicatorColor='primary'
                                         textColor='primary'
-                                        style={{minHeight: '24px', flexGrow: 1}}
+                                        sx={{minHeight: '24px', flexGrow: 1}}
                                     >
                                         <Tab
+                                            disableRipple
                                             label='PREFERENCES'
-                                            style={{
+                                            sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
@@ -301,8 +305,9 @@ export class UserDialog extends React.Component<IProps, IState> {
                                             value={Page.PREFERENCES}
                                         />
                                         <Tab
+                                            disableRipple
                                             label='LIMITS'
-                                            style={{
+                                            sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
@@ -310,8 +315,9 @@ export class UserDialog extends React.Component<IProps, IState> {
                                             value={Page.LIMITS}
                                         />
                                         <Tab
+                                            disableRipple
                                             label='CONNECTORS'
-                                            style={{
+                                            sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
@@ -319,39 +325,40 @@ export class UserDialog extends React.Component<IProps, IState> {
                                             value={Page.CONNECTORS}
                                         />
                                         <Tab
-                                            label='PAYMENTS'
-                                            style={{
-                                                padding: '0px',
-                                                minWidth: 'auto',
-                                                minHeight: '36px',
-                                            }}
-                                            value={Page.PAYMENT}
-                                        />
-                                        <Tab
+                                            disableRipple
                                             label='FILES'
-                                            style={{
+                                            sx={{
                                                 padding: '0px',
                                                 minWidth: 'auto',
                                                 minHeight: '36px',
                                             }}
                                             value={Page.FILES}
                                         />
+                                        <Tab
+                                            disableRipple
+                                            label='BILLING'
+                                            sx={{
+                                                padding: '0px',
+                                                minWidth: 'auto',
+                                                minHeight: '36px',
+                                            }}
+                                            value={Page.BILLING}
+                                        />
                                     </Tabs>
-                                    <div style={{
+                                    <DIV sx={{
 										margin: '12px',
 										color: 'var(--jp-ui-font-color3)',
 										textAlign: 'center',
 										fontSize: '10px',
-										fontStyle: 'italic',
 									}}>
                                         Version {Global.version}
-                                    </div>
-                                </div>
+                                    </DIV>
+                                </DIV>
                             </DialogContent>
-                        </div>
+                        </DIV>
                         <ShadowedDivider orientation='vertical' />
-                        <div style={{display: 'flex', flexFlow: 'column', overflow: 'hidden', width: 'calc(100% - 150px)', height: '100%'}}>
-                            <DialogContent style={{
+                        <DIV sx={{display: 'flex', flexFlow: 'column', overflow: 'hidden', width: 'calc(100% - 150px)', height: '100%'}}>
+                            <DialogContent sx={{
                                 flexGrow: 1, 
                                 overflowY: 'auto',
                                 width: '100%',
@@ -362,20 +369,20 @@ export class UserDialog extends React.Component<IProps, IState> {
                                 fontSize: 'var(--jp-ui-font-size1)',
                                 fontFamily: 'var(--jp-ui-font-family)',
                             }}>
-                                <div style={{
+                                <DIV sx={{
                                     // Height needs to be 100% otherwise it will cause problems with the phone number country selection
                                     display: 'flex', flexFlow: 'column', overflow: 'hidden', height: '100%'
                                 }}>
                                     {this.state.selectedPanel == Page.PREFERENCES ? (
                                         <>
-                                            {/* <div style={{display: 'flex', padding: '6px 6px 0px 6px', maxWidth: '450px'}}>
-                                                <div style={{width: '68px', margin: '0px 6px'}}>
-                                                    <div style={{
+                                            {/* <DIV sx={{display: 'flex', padding: '6px 6px 0px 6px', maxWidth: '450px'}}>
+                                                <DIV sx={{width: '68px', margin: '0px 6px'}}>
+                                                    <DIV sx={{
                                                         width: '48px',
                                                         height: '48px',
                                                         margin: '6px auto',
                                                         borderRadius: '24px',
-                                                        backgroundColor: '#10A0F9',
+                                                        backgroundColor: Colors.PRIMARY,
                                                         color: 'white',
                                                         fontSize: (28 - defaultProfilePicture.length * 4) + 'px',
                                                         fontWeight: 'bold',
@@ -383,47 +390,55 @@ export class UserDialog extends React.Component<IProps, IState> {
                                                         textAlign: 'center'
                                                     }}>
                                                         {defaultProfilePicture}
-                                                    </div>
-                                                </div>
-                                                <div style={{display: 'table', height: '48px', margin: '6px', flexGrow: 1}}>
-                                                    <div style={{display: 'table-cell', verticalAlign: 'middle'}}>
-                                                        <span style={{fontSize: '16px', lineHeight: '1', fontWeight: 'normal'}}>
+                                                    </DIV>
+                                                </DIV>
+                                                <DIV sx={{display: 'table', height: '48px', margin: '6px', flexGrow: 1}}>
+                                                    <DIV sx={{display: 'table-cell', verticalAlign: 'middle'}}>
+                                                        <SPAN sx={{fontSize: '16px', lineHeight: '1', fontWeight: 'normal'}}>
                                                             {Global.user.name}
-                                                        </span>
+                                                        </SPAN>
                                                         <br />
-                                                    </div>
-                                                </div>
-                                            </div> */}
+                                                    </DIV>
+                                                </DIV>
+                                            </DIV> */}
                                             <AccountPreferencesSubMenu
-                                                style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}}
+                                                sx={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}}
                                                 phoneValidOnBlur={(valid: boolean) => {
                                                     this.setState({ validPhoneNumber: valid });
                                                 }}
                                             />
                                         </>
                                     ) : this.state.selectedPanel == Page.LIMITS ? (
-                                        <AccountLimitsSubMenu style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
-                                    ) : this.state.selectedPanel == Page.PAYMENT ? (
-                                        <AccountPaymentSubMenu style={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
+                                        <AccountLimitsSubMenu sx={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}} />
+                                    ) : this.state.selectedPanel == Page.BILLING ? (
+                                        <AccountBillingSubMenu
+                                            sx={{flexGrow: 1, overflowY: 'auto', maxWidth: '450px'}}
+                                            balance={this.props.balance}
+                                            machineCost={this.props.machineCost}
+                                            serviceFeeCost={this.props.serviceFeeCost}
+                                            storageCost={this.props.storageCost}
+                                            egressCost={this.props.egressCost}
+                                        />
                                     ) : this.state.selectedPanel == Page.CONNECTORS ? (
-                                        <AccountConnectorsSubMenu style={{flexGrow: 1, overflowY: 'auto'}} />
+                                        <AccountConnectorsSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
                                     ) : this.state.selectedPanel == Page.FILES && (
-                                        <AccountFilesSubMenu style={{flexGrow: 1, overflowY: 'auto'}} />
+                                        <AccountFilesSubMenu sx={{flexGrow: 1, overflowY: 'auto'}} />
                                     )}
-                                </div>
+                                </DIV>
                             </DialogContent>
-                        </div>
-                    </div>
-                    <div style={{display: 'inline-flex'}}>
+                        </DIV>
+                    </DIV>
+                    <DIV sx={{display: 'inline-flex'}}>
                         
-                    </div>
+                    </DIV>
 				</StyledDialog>
-            </div>
-        )
+            </DIV>
+        );
     }
 
     // Log out of the REST interface
 	private logout() {
+        Global.user = null;
 		const settings = ServerConnection.makeSettings();
 		const url = settings.baseUrl + "optumi/logout";
 		const init = {
@@ -433,9 +448,7 @@ export class UserDialog extends React.Component<IProps, IState> {
 			url,
 			init, 
 			settings
-		).then((response: Response) => {
-			Global.user = null;
-		});		
+		);
 	}
 
     public componentDidMount = () => {
