@@ -5,10 +5,14 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Input, withStyles } from '@material-ui/core';
 import * as React from 'react';
-import { Global } from '../../Global';
-import { Edit } from '@material-ui/icons';
+import { DIV, Global } from '../../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Input } from '@mui/material';
+import { withStyles } from '@mui/styles';
+import { Edit } from '@mui/icons-material';
+
 const StyledInput = withStyles({
     root: {
         fontSize: 'var(--jp-ui-font-size1)', 
@@ -21,10 +25,10 @@ const StyledInput = withStyles({
     },
     underline: {
         '&:hover:before': {
-            borderBottom: '1px solid rgba(0, 0, 0, 0.87) !important',
+            borderBottomWidth: '1px !important',
         },
-        '&::before': {
-            borderBottom: 'none',
+        '&:before': {
+            borderBottomWidth: '0px',
         },
     },
 })(Input);
@@ -33,7 +37,7 @@ interface IProps {
     getValue: () => string
     saveValue: (value: string) => void
     placeholder: string
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {
@@ -57,7 +61,7 @@ export class AnnotationInput extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={{position: 'relative'}}>
+            <DIV sx={{position: 'relative', display: 'inline-flex'}}>
                 <StyledInput
                     inputRef={this.textField}
                     value={this.state.value}
@@ -73,8 +77,8 @@ export class AnnotationInput extends React.Component<IProps, IState> {
                     onBlur={() => this.props.saveValue(this.state.value)}
                     placeholder={this.props.placeholder}
                 />
-                 <Edit style={{opacity: this.state.value == '' ? 0.5 : 0, height: '12px', width: '12px', margin: '4px 0px', position: 'absolute', left: Math.min(Global.getStringWidth(this.state.value == "" ? this.props.placeholder : this.state.value, '13px Roboto, Helvetica, Arial, sans-serif'), 200) + 'px' }} />
-            </div>
+                 <Edit sx={{opacity: this.state.value == '' ? 0.5 : 0, height: '12px', width: '12px', margin: '4px', position: 'absolute', left: Math.min(Global.getStringWidth(this.state.value == "" ? this.props.placeholder : this.state.value, '13px Roboto, Helvetica, Arial, sans-serif'), 200) + 'px' }} />
+            </DIV>
         )
     }
 
