@@ -5,19 +5,21 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
 import * as React from 'react'
-import { Global } from '../../Global';
+import { DIV, Global } from '../../Global';
+
+import { SxProps, Theme } from '@mui/system';
+
 import { DataConnectorMetadata } from './dataConnectorBrowser/DataConnectorBrowser';
 import DataConnectorDirListingItem from './dataConnectorBrowser/DataConnectorDirListingItem';
 import { DataService } from './dataConnectorBrowser/DataConnectorDirListingItemIcon';
-
+import { Colors } from '../../Colors';
 
 interface IProps {
     dataService: DataService;
     description?: string;
     handleClick?: () => any;
-    style?: CSSProperties;
+    sx?: SxProps<Theme>;
 }
 
 interface IState {}
@@ -27,7 +29,7 @@ export class DataConnectorIdentity extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({}, this.props.style)}>
+            <DIV sx={Object.assign({}, this.props.sx)}>
                 <DataConnectorDirListingItem
                         key={this.props.dataService}
                         dataConnectorMetadata={{
@@ -37,30 +39,30 @@ export class DataConnectorIdentity extends React.Component<IProps, IState> {
                         selected={false}
                         handleButtonClick={this.props.handleClick}
                         buttonText='Create'
-                        buttonColor='#10A0F9'
+                        buttonColor={Colors.PRIMARY}
                         onClick={() => false}
                         onDoubleClick={() => false}
                     />
-            </div>
-            // <div style={{margin: '6px'}}>
-            //     <div style={{display: 'inline-flex', width: '100%', height: '40px'}}>
-            //         <div className={this.props.iconClass} style={{width: '30px', margin: '6px 6px 6px 12px'}}/>
-            //         <div style={{margin: 'auto 6px', lineHeight: '14px', width: this.props.description && '92px'}}>
-            //             <div style={{fontWeight: 'bold'}}>
+            </DIV>
+            // <DIV sx={{margin: '6px'}}>
+            //     <DIV sx={{display: 'inline-flex', width: '100%', height: '40px'}}>
+            //         <DIV className={this.props.iconClass} sx={{width: '30px', margin: '6px 6px 6px 12px'}}/>
+            //         <DIV sx={{margin: 'auto 6px', lineHeight: '14px', width: this.props.description && '92px'}}>
+            //             <DIV sx={{fontWeight: 'bold'}}>
             //                 {this.props.provider}
-            //             </div>
+            //             </DIV>
             //             {this.props.service != '' && (
-            //                 <div>
+            //                 <DIV>
             //                     {this.props.service}
-            //                 </div>
+            //                 </DIV>
             //             )}
-            //         </div>
-            //         {this.props.description && <div style={{flexGrow: 1, margin: 'auto 12px', maxWidth: '160px'}}>
+            //         </DIV>
+            //         {this.props.description && <DIV sx={{flexGrow: 1, margin: 'auto 12px', maxWidth: '160px'}}>
             //             {this.props.description}
-            //         </div>}
+            //         </DIV>}
             //         {this.props.handleClick && <Button
             //             onClick={this.props.handleClick}
-            //             style={{
+            //             sx={{
             //             //     padding: '6px',
             //             //     fontWeight: 'bold',
             //             //     height: '24px',
@@ -72,8 +74,8 @@ export class DataConnectorIdentity extends React.Component<IProps, IState> {
             //         >
             //             Create   
             //         </Button>}
-            //     </div>
-            // </div>
+            //     </DIV>
+            // </DIV>
         )
     }
 }
