@@ -5,12 +5,14 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Dialog, IconButton, withStyles } from '@material-ui/core';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { AddAlert, Close } from '@material-ui/icons';
 import * as React from 'react'
-import { Global } from '../../Global';
-import DialogTitle from '@material-ui/core/DialogTitle';
+import { DIV, Global } from '../../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Dialog, DialogTitle, IconButton } from '@mui/material';
+import { withStyles } from '@mui/styles';
+import { AddAlert, Close } from '@mui/icons-material';
+
 import { ShadowedDivider } from '../../core';
 import { OptumiConfig } from '../../models/OptumiConfig';
 import { NotificationContent } from '../../core/NotificationContent'
@@ -21,13 +23,12 @@ const StyledDialog = withStyles({
         // width: '100%',
         height: '80%',
         overflowY: 'visible',
-        backgroundColor: 'var(--jp-layout-color1)',
         maxWidth: 'inherit',
     },
 })(Dialog);
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     onOpen?: () => void
     onClose?: () => void
     disabled?: boolean
@@ -66,44 +67,41 @@ export class NotificationsPopup extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({margin: 'auto'}, this.props.style)}>
+            <DIV sx={Object.assign({margin: 'auto'}, this.props.sx)}>
                 <IconButton
+                    size='large'
                     onClick={this.handleClickOpen}
-                    style={{padding: '0px', marginRight: '-3px', width: '30px', height: '30px'}}
+                    sx={{padding: '0px', marginRight: '-3px', width: '30px', height: '30px'}}
                     disabled={this.props.disabled}
-                    >
-                    <AddAlert style={{height: '21px'}}/>
+                >
+                    <AddAlert sx={{height: '21px'}}/>
                 </IconButton>
                 <StyledDialog
 					open={this.state.open}
 					onClose={this.handleClose}
                     scroll='paper'
 				>
-					<DialogTitle
-					    disableTypography
-                        style={{
-                            display: 'inline-flex',
-                            backgroundColor: 'var(--jp-layout-color2)',
-                            height: '60px',
-                            padding: '6px',
-                            borderRadius: '4px',
-                        }}
-                    >
-                        <div style={{
+					<DialogTitle sx={{
+                        display: 'inline-flex',
+                        height: '60px',
+                        padding: '6px',
+                    }}>
+                        <DIV sx={{
                             display: 'inline-flex',
                             minWidth: '225px',
                             fontSize: '16px',
                             fontWeight: 'bold',
                             paddingRight: '12px', // this is 6px counteracting the DialogTitle padding and 6px aligning the padding to the right of the tabs
                         }}>
-                            <div style={{margin: 'auto', paddingLeft: '12px'}}>
+                            <DIV sx={{margin: 'auto', paddingLeft: '12px'}}>
             					Configure Notifications
-                            </div>
-                        </div>
-                        <div style={{flexGrow: 1}} />
+                            </DIV>
+                        </DIV>
+                        <DIV sx={{flexGrow: 1}} />
                         <IconButton
+                            size='large'
                             onClick={this.handleClose}
-                            style={{
+                            sx={{
                                 display: 'inline-block',
                                 width: '36px',
                                 height: '36px',
@@ -112,7 +110,7 @@ export class NotificationsPopup extends React.Component<IProps, IState> {
                             }}
                         >
                             <Close
-                                style={{
+                                sx={{
                                     width: '30px',
                                     height: '30px',
                                     padding: '3px',
@@ -121,7 +119,7 @@ export class NotificationsPopup extends React.Component<IProps, IState> {
                         </IconButton>
 					</DialogTitle>
                     <ShadowedDivider />
-                    <div style={{
+                    <DIV sx={{
                         padding: '12px',
                         fontSize: 'var(--jp-ui-font-size1)',
                     }}>
@@ -135,10 +133,10 @@ export class NotificationsPopup extends React.Component<IProps, IState> {
                             openUserDialogTo={this.props.openUserDialogTo}
                             handleClose={this.handleClose}
                         />
-                    </div>
+                    </DIV>
 				</StyledDialog>
-            </div>
-        )
+            </DIV>
+        );
     }
 
     public componentDidMount = () => {
