@@ -6,16 +6,22 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../Global';
+import { DIV, Global } from '../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { Machine, NoMachine } from '../../models/machine/Machine';
 import { App } from '../../models/application/App';
 import { LightweightApp } from '../../models/application/LightweightApp';
 import { StatusWrapper } from '../StatusWrapper';
+import { ComputeConfig } from '../../models/ComputeConfig';
+import { StorageConfig } from '../../models/StorageConfig';
+import { GraphicsConfig } from '../../models/GraphicsConfig';
+import { MemoryConfig } from '../../models/MemoryConfig';
 
 // Properties from parent
 interface IProps {
-	style?: React.CSSProperties
+	sx?: SxProps<Theme>
 }
 
 // Properties for this component
@@ -30,6 +36,7 @@ export class PreviewLaunchButton extends React.Component<IProps, IState> {
 	// We need to know if the component is mounted to change state
 	_isMounted = false;
 	polling = false;
+	timeout: NodeJS.Timeout = null
 
 	constructor(props: IProps) {
 		super(props);
@@ -42,13 +49,15 @@ export class PreviewLaunchButton extends React.Component<IProps, IState> {
 		// We will poll for a new preview every 10 seconds
 		if (this.polling) {
 			if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-			setTimeout(() => this.poll(), 10000);
+			this.timeout = setTimeout(() => this.poll(), 10000);
 		}
 		this.handlePreviewClick(false);
 	}
 
 	// To understand whats going on, look at the commented out functions below
 	private handlePreviewClick = (printRecommendations: boolean, bypassLimiter?: boolean) => {
+		// For basic mode, we do not need to retrieve a preview, since we know the exact machine
+		if (!Global.expertModeSelected) return;
 		const current = Global.tracker.currentWidget;
 		if (current != null) {
 			const config = Global.metadata.getMetadata().config;
@@ -56,22 +65,27 @@ export class PreviewLaunchButton extends React.Component<IProps, IState> {
 			// current.context.save();
             // Make sure the notebook has the correct metadata.
 			if (bypassLimiter || !retrievingPreview) {
-				retrievingPreview = true;
-				const app = new App(current.context.path, current.model.toJSON(), config);
-				app.previewNotebook(printRecommendations).then((machines: Machine[]) => {
-					this.safeSetState({
-						machine: machines,
-					});
-					Global.lastMachine = machines[0]
-					if (updatePreviewAgain) {
-						updatePreviewAgain = false;
-						this.handlePreviewClick(false, true);
-					} else {
+				try {
+					retrievingPreview = true;
+					const app = new App(current.context.path, current.model.toJSON(), config);
+					app.previewNotebook(printRecommendations).then((machines: Machine[]) => {
+						this.safeSetState({
+							machine: machines,
+						});
+						Global.lastMachine = machines[0]
+						if (updatePreviewAgain) {
+							updatePreviewAgain = false;
+							this.handlePreviewClick(false, true);
+						} else {
+							retrievingPreview = false;
+						}
+					}, () => {
 						retrievingPreview = false;
-					}
-				}, () => {
+					});
+				} catch (err) {
+					console.error(err);
 					retrievingPreview = false;
-				});
+				}
 			} else {
 				updatePreviewAgain = true;
 			}
@@ -119,36 +133,90 @@ export class PreviewLaunchButton extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         // var order = 1;
 		const metadata = Global.metadata.getMetadata();
+		const machine = (Global.expertModeSelected ? this.state.machine[0] : Global.user.machines.getMachine(Global.metadata.getMetadata().config.machineAssortment[0]));
 		return (
-			<div style={Object.assign({width: '100%'}, this.props.style)}>
-				{React.cloneElement(this.state.machine[0].getPreviewComponent(), {style: {}})}
-				<div style={{margin: '6px 0px 6px 6px'}}>
+			<DIV sx={Object.assign({width: '100%'}, this.props.sx)}>
+				{React.cloneElement(machine.getPreviewComponent(), {style: {}})}
+				<DIV sx={{margin: '6px'}}>
 					<StatusWrapper statusColor={'var(--jp-layout-color2)'}>
-						{new LightweightApp(metadata.metadata.nbKey, Global.tracker.currentWidget.context.path, metadata.config).getLaunchComponent(this.state.machine[0] instanceof NoMachine)}
+						{new LightweightApp(metadata.metadata.nbKey, Global.tracker.currentWidget.context.path, metadata.config).getLaunchComponent(machine instanceof NoMachine)}
 					</StatusWrapper>
-				</div>
-				{/* {Global.user.userExpertise < 2 ? (<></>) : (this.state.machine.splice(1).map(x => (<div style={{marginTop: '12px'}}>{x.getLaunchComponent(order++)}</div>)))} */} {/* Not sure how this is supposed to translate to the new method of launching */}
-			</div>
+				</DIV>
+				{/* {Global.user.userExpertise < 2 ? (<></>) : (this.state.machine.splice(1).map(x => (<DIV sx={{marginTop: '12px'}}>{x.getLaunchComponent(order++)}</DIV>)))} */} {/* Not sure how this is supposed to translate to the new method of launching */}
+			</DIV>
 		);
 	}
 
 	// We need to force update in case the preview doesn't change but the metadata does
-	private handleMetadataChange = () => { this.forceUpdate(), this.handlePreviewClick(false) }
+	private handleMetadataChange = () => {
+		try {
+			const optumi = Global.metadata.getMetadata();
+			var changed:boolean = false
+			if (Global.expertModeSelected) {
+				// In expert mode, we do not want any specified VM sizes
+				if (optumi.config.machineAssortment.length > 0) {
+					optumi.config.machineAssortment = []
+					changed = true
+				}
+			} else {
+				// In basic mode, we do not want any config except vm sizes
+				if (JSON.stringify(optumi.config.compute) != JSON.stringify(new ComputeConfig())) {
+					optumi.config.compute = new ComputeConfig();
+					changed = true;
+				}
+				if (JSON.stringify(optumi.config.graphics) != JSON.stringify(new GraphicsConfig())) {
+					optumi.config.graphics = new GraphicsConfig();
+					changed = true;
+				}
+				if (JSON.stringify(optumi.config.memory) != JSON.stringify(new MemoryConfig())) {
+					optumi.config.memory = new MemoryConfig();
+					changed = true;
+				}
+				if (JSON.stringify(optumi.config.storage) != JSON.stringify(new StorageConfig())) {
+					optumi.config.storage = new StorageConfig();
+					changed = true;
+				}
+				if (optumi.config.intent != 0.5) {
+					optumi.config.intent = 0.5;
+					changed = true;
+				}
+				// We need one VM size for basic mode
+				if (optumi.config.machineAssortment.length == 0) {
+					optumi.config.machineAssortment = ['Azure:Standard_NC4as_T4_v3']
+					changed = true;
+				}
+			}
+			if (changed) {
+				Global.metadata.setMetadata(optumi);
+			}
+		} catch (err) {
+			console.error(err);
+		}
+
+		this.forceUpdate()
+		this.handlePreviewClick(false)
+	}
 
 	// Will be called automatically when the component is mounted
 	public componentDidMount = () => {
 		this._isMounted = true;
+
+		this.handleMetadataChange();
+
 		this.polling = true;
 		this.poll();
 		Global.metadata.getMetadataChanged().connect(this.handleMetadataChange);
-		this.handlePreviewClick(false);
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
+		this.polling = false;
+		if (this.timeout != null) {
+			clearTimeout(this.timeout);
+			retrievingPreview = false;
+		}
 		Global.metadata.getMetadataChanged().disconnect(this.handleMetadataChange);
 		this._isMounted = false;
-		this.polling = false;
 	}
 
 	private safeSetState = (map: any) => {
