@@ -6,15 +6,10 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../Global';
+import { DIV, Global } from '../../Global';
 
-import {
-	Tabs,
-	Tab,
-} from '@material-ui/core';
-
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import withStyles from '@material-ui/core/styles/withStyles';
+import { Tabs, Tab } from '@mui/material';
+import { CSSProperties, withStyles } from '@mui/styles';
 
 const StyledTab = withStyles({
     root: {
@@ -55,25 +50,27 @@ export class RequirementsBar extends React.Component<IProps, IState> {
 	public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
 		return (
-			<div style={{width: '100%', textAlign: 'center'}}>
+			<DIV sx={{width: '100%', textAlign: 'center'}}>
 				<Tabs 
                     value={this.state.page}
                     onChange={this.handleTabChange}
                     variant="fullWidth"
                     indicatorColor="primary"
                     textColor="primary"
-                    style={{padding: "0px 6px 0px 6px", minHeight: "24px"}}
+                    sx={{padding: "0px 6px 0px 6px", minHeight: "24px"}}
                 >
 					<StyledTab
+						disableRipple
                         label="RESOURCES"
-                        style={{minWidth: "100px"}}
+                        sx={{minWidth: "100px"}}
 					/>
 					<StyledTab
+						disableRipple
                         label="FILES"
-                        style={{minWidth: "100px"}}
+                        sx={{minWidth: "100px"}}
 					/>
 				</Tabs>
-			</div>
+			</DIV>
 		);
 	}
 
