@@ -6,10 +6,12 @@
 **/
 
 import * as React from 'react'
+import { Colors } from '../../../Colors';
+import { Global, UL } from '../../../Global';
+
 import { DataConnectorMetadata } from './DataConnectorBrowser'
 import DataConnectorDirListingItem from './DataConnectorDirListingItem'
 import { DataService } from './DataConnectorDirListingItemIcon'
-import { Global } from '../../../Global';
 
 interface IProps {
     filter: string
@@ -44,7 +46,7 @@ export default class DataConnectorDirListingContent extends React.Component<IPro
         const filter = (dataConnector: DataConnectorMetadata) => dataConnector.name.replace(new RegExp('^' + this.props.filter.replace(/(.)/gi, '[^$1]*$1') + '.*$', 'i'), '').length === 0;
         const sortedDataConnectors = this.props.dataConnectors.filter(filter).sort(this.props.sort)
         return (
-            <ul className='jp-DirListing-content' style={{overflowY: 'auto'}}>
+            <UL className='jp-DirListing-content' sx={{overflowY: 'auto'}}>
                 {sortedDataConnectors.length == 0 ? (
                     <>
                         <DataConnectorDirListingItem
@@ -67,7 +69,7 @@ export default class DataConnectorDirListingContent extends React.Component<IPro
                                 selected={this.state.selected.includes(dataConnector)}
                                 handleButtonClick={this.props.handleDelete}
                                 buttonText='Delete'
-                                buttonColor='#f48f8d'
+                                buttonColor={Colors.ERROR}
                                 onClick={(event: React.MouseEvent<HTMLLIElement, MouseEvent>) => {
                                     if (this.props.getSelected === undefined) return; // If someone doesn't want what is selected, don't select.
                                     if (this.firstClicked === undefined) {
@@ -111,7 +113,7 @@ export default class DataConnectorDirListingContent extends React.Component<IPro
                         ))}
                     </>
                 )}
-            </ul>
+            </UL>
         )
     }
 
