@@ -6,8 +6,9 @@
 **/
 
 import * as React from 'react'
+import { Global, SPAN } from '../../../Global';
+
 import { FileMetadata } from './FileBrowser'
-import { Global } from '../../../Global';
 
 interface IProps {
     file: FileMetadata
@@ -26,10 +27,10 @@ export default class BreadCrumbItem extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
-                <span className='jp-BreadCrumbs-item' title={this.props.file.path} onClick={() => this.props.onOpen(this.props.file)}>
+                <SPAN className='jp-BreadCrumbs-item' title={this.props.file.path} onClick={() => this.props.onOpen(this.props.file)}>
                     ...
-                </span>
-                <span>/</span>
+                </SPAN>
+                <SPAN>/</SPAN>
             </>
         )
     }
