@@ -6,10 +6,13 @@
 **/
 
 import * as React from 'react'
+import { Global, UL } from '../../../Global';
+
+import { StringExt } from '@lumino/algorithm';
+
 import DirListingItem from './DirListingItem'
 import { FileMetadata } from './FileBrowser'
-import { Global } from '../../../Global';
-import { StringExt } from '@lumino/algorithm';
+
 
 interface IProps {
     filter: string
@@ -66,7 +69,7 @@ export default class DirListingContent extends React.Component<IProps, IState> {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const sortedFiles = this.props.files.map(x => new FilterableFile(x)).filter(this.filter).sort((a, b) => this.props.sort(a.file, b.file))
         return (
-            <ul className='jp-DirListing-content' style={{overflowY: 'auto'}}>
+            <UL className='jp-DirListing-content' sx={{overflowY: 'auto'}}>
                 {sortedFiles.map(filteredFile => (
                     <DirListingItem
                         key={filteredFile.file.path + filteredFile.file.name}
@@ -113,7 +116,7 @@ export default class DirListingContent extends React.Component<IProps, IState> {
                         }}
                     />
                 ))}
-            </ul>
+            </UL>
         )
     }
 
