@@ -6,15 +6,18 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { Slider } from '../../../core';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import { ComputeConfig } from '../../../models/ComputeConfig';
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -40,17 +43,17 @@ export class ComputeSimplified extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var user: User = Global.user;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <Slider
                     getValue={this.getCoresValue}
                     saveValue={this.saveCoresValue}
                     minValue={-1}
-                    maxValue={user.machines.absoluteComputeMaxCores}
+                    maxValue={user.machines.computeCoresMax}
                     label={'Cores'}
-                    color={'#f48f8d'}
+                    color={Colors.CPU}
                     showUnit
                 />
-            </div>
+            </DIV>
         )
     }
 
