@@ -6,16 +6,19 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { Slider } from '../../../core';
 import { GraphicsConfig } from '../../../models/GraphicsConfig';
 import { User } from '../../../models/User';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import FormatUtils from '../../../utils/FormatUtils';
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -86,14 +89,14 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var user: User = Global.user;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <Slider
                     getValue={this.getCoresValue}
                     saveValue={this.saveCoresValue}
                     minValue={-1}
                     maxValue={user.machines.graphicsCoresMax}
                     label={'Cores'}
-                    color={'#ffba7d'}
+                    color={Colors.GPU}
                     showUnit
                 />
                 <Slider
@@ -102,7 +105,7 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
                     minValue={-1}
                     maxValue={user.machines.graphicsScoreMax}
                     label={'Score'}
-                    color={'#ffba7d'}
+                    color={Colors.GPU}
                     showUnit
                 />
                 <Slider
@@ -112,7 +115,7 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
                     step={1000000}
                     maxValue={user.machines.graphicsFrequencyMax}
                     label={'Frequency'}
-                    color={'#ffba7d'}
+                    color={Colors.GPU}
                     showUnit
                     styledUnit={FormatUtils.styleFrequencyUnit()}
                     styledValue={FormatUtils.styleFrequencyValue()}
@@ -125,13 +128,13 @@ export class GraphicsComponent extends React.Component<IProps, IState> {
                     step={1048576}
                     maxValue={user.machines.graphicsMemoryMax}
                     label={'Memory'}
-                    color={'#ffba7d'}
+                    color={Colors.GPU}
                     showUnit
                     styledUnit={FormatUtils.styleCapacityUnit()}
                     styledValue={FormatUtils.styleCapacityValue()}
                     unstyledValue={FormatUtils.unstyleCapacityValue()}
                 />
-            </div>
+            </DIV>
         )
     }
 
