@@ -5,60 +5,23 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Accordion, AccordionDetails, AccordionSummary, IconButton, withStyles } from '@material-ui/core';
-import { ExpandMore } from '@material-ui/icons';
 import * as React from 'react';
+import { DIV, Global, P, SPAN, StyledAccordion, StyledAccordionDetails, StyledAccordionSummary } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { IconButton } from '@mui/material';
+import { ExpandMore } from '@mui/icons-material';
+
 import { SubHeader } from '../../../core';
 // import { EmbeddedYoutube } from '../../../core/EmbeddedYoutube';
 import { InfoPopup } from '../../../core/InfoPoppup';
-import { Global } from '../../../Global';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import ExtraInfo from '../../../utils/ExtraInfo';
-
 import { OutlinedResourceRadio } from '../OutlinedResourceRadio';
-
-const StyledAccordion = withStyles({
-    root: {
-        borderWidth: '0px',
-        '&.Mui-expanded': {
-            margin: '0px',
-        },
-        '&:before': {
-            backgroundColor: 'unset',
-        },
-    },
-})(Accordion)
-
-const StyledAccordionSummary = withStyles({
-    root: {
-        padding: '0px',
-        minHeight: '0px',
-        '&.Mui-expanded': {
-            minHeight: '0px',
-        },
-    },
-    content: {
-        margin: '0px',
-        '&.Mui-expanded': {
-            margin: '0px',
-        },
-    },
-    expandIcon: {
-        padding: '0px',
-        marginRight: '0px',
-    },
-})(AccordionSummary)
-
-const StyledAccordionDetails = withStyles({
-    root: {
-        display: 'flex',
-        flexDirection: 'column',
-        padding: '0px',
-    },
-})(AccordionDetails)
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -84,50 +47,49 @@ export class LaunchMode extends React.Component<IProps, IState> {
         const value = this.getValue();
         const optumi = Global.metadata.getMetadata().config;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <StyledAccordion
                     variant={'outlined'}
                     expanded={Global.launchModeAccordionExpanded}
-                    style={{background: 'var(--jp-layout-color1)'}}
+                    sx={{background: 'var(--jp-layout-color1)'}}
                 >
-                    <StyledAccordionSummary style={{cursor: 'default'}}>
-                        <div style={{display: 'flex'}}>
-                            <SubHeader title='Launch Mode'/>
+                    <StyledAccordionSummary sx={{cursor: 'default'}}>
+                        <DIV sx={{display: 'flex'}}>
+                            <SubHeader title='Launch mode'/>
                             <InfoPopup
-                                title='Launch Mode'
+                                title='Launch mode'
                                 popup={
-                                    <div style={{margin: '12px'}}>
-                                        <p style={{whiteSpace: 'pre-line'}}>
+                                    <DIV sx={{margin: '12px'}}>
+                                        <P sx={{whiteSpace: 'pre-line'}}>
                                             {`The selected launch mode determines how your notebook will be run in the cloud.`}
-                                        </p>
-                                        <p style={{whiteSpace: 'pre-line', textDecoration: 'underline', marginBottom: '0'}}>
-                                            {`Session`}
-                                        </p>
-                                        <p style={{whiteSpace: 'pre-line'}}>
-                                            {`If selected, Optumi will start a JupyterLab server in the cloud that you will connect to via browser. A new browser tab will open automatically when the session begins running. You will be able to work interactively, the same way you do in local JupyterLab, however notebook execution will take place on the remote server.
+                                        </P>
+                                        <P sx={{whiteSpace: 'pre-line', fontWeight: 'bold', marginBottom: '0'}}>
+                                            {`session`}
+                                        </P>
+                                        <P sx={{whiteSpace: 'pre-line'}}>
+                                            {`If selected, Optumi will start a JupyterLab server in the cloud that you will connect to with your browser. A new browser tab will open automatically when the session is ready for use. You will be able to work interactively the same way you do on your local laptop, however notebook execution will take place on the remote server.
 
-                                            This is often useful when developing or debugging your code.`}
-                                        </p>
-                                        <p style={{whiteSpace: 'pre-line', textDecoration: 'underline', marginBottom: '0'}}>
-                                            {`Job`}
-                                        </p>
-                                        <p style={{whiteSpace: 'pre-line'}}>
-                                            {`If selected, Optumi will take a snapshot of your notebook and execute it in the cloud, from start to finish. You will be able to see the notebook output as your job progresses, however you won’t be able to interact with the notebook.
+                                            This is often useful when developing or debugging your notebook.`}
+                                        </P>
+                                        <P sx={{whiteSpace: 'pre-line', fontWeight: 'bold', marginBottom: '0'}}>
+                                            {`job`}
+                                        </P>
+                                        <P sx={{whiteSpace: 'pre-line'}}>
+                                            {`If selected, Optumi will take a snapshot of your current notebook and execute it in the cloud from start to finish. You will be able to see the notebook output as your job progresses, however you won’t be able to re-run individual cells within the notebook.
 
-                                            This is often useful when training or hyperparameter tuning. You can think of it as a “fire and forget” mode where you are free to shut your laptop without impacting notebook execution.
-                                            `}
-                                        </p>
+                                            This is often useful when training or tuning hyperparameters. You can think of it as a fire-and-forget mode where you are free to close your browser without disrupting notebook execution.`}
+                                        </P>
                                         {/* <EmbeddedYoutube
                                             name='Demo'
                                             url={'https://www.youtube.com/watch?v=MXzv-XL6LLs'}
                                             width={700}
                                             height={480}
                                         /> */}
-                                    </div>
+                                    </DIV>
                                 }
                             />
-                        </div>
-                        <span style={{
+                        </DIV>
+                        <SPAN sx={{
                             margin: 'auto 15px',
                             flexGrow: 1,
                             textAlign: 'end',
@@ -137,37 +99,38 @@ export class LaunchMode extends React.Component<IProps, IState> {
                             fontSize: '12px',
                             fontStyle: 'italic',
                         }}>
-                            {optumi.interactive ? 'Session' : 'Job'}
-                        </span>
+                            {optumi.interactive ? 'session' : 'job'}
+                        </SPAN>
                         <IconButton
+                            size='large'
                             onClick={() => {
                                 Global.launchModeAccordionExpanded = !Global.launchModeAccordionExpanded
                                 if (this._isMounted) this.forceUpdate();
                             }}
-                            style={{padding: '0px', marginRight: '-3px', width: '30px', transform: Global.packagesAccordionExpanded ? 'rotate(180deg)' : undefined}}
+                            sx={{padding: '0px', marginRight: '-3px', width: '30px', transform: Global.launchModeAccordionExpanded ? 'rotate(180deg)' : undefined}}
                         >
                             <ExpandMore />
                         </IconButton>
                     </StyledAccordionSummary>
                     <StyledAccordionDetails>
-                        <div
-                            style={{
+                        <DIV
+                            sx={{
                                 alignItems: 'center',
                                 display: 'inline-flex',
                                 width: '100%',
                             }}
                         >
                             <ExtraInfo reminder='Run an interactive session'>
-                                <OutlinedResourceRadio label={'Session'} color={'#afaab0'} selected={value == "Session"} handleClick={() => this.saveValue("Session")}/>
+                                <OutlinedResourceRadio label={'Session'} color={Colors.SECONDARY} selected={value == "Session"} handleClick={() => this.saveValue("Session")}/>
                             </ExtraInfo>
                             <ExtraInfo reminder='Run a batch job'>
-                                <OutlinedResourceRadio label={"Job"} color={'#afaab0'} selected={value == "Job"} handleClick={() => this.saveValue("Job")}/>
+                                <OutlinedResourceRadio label={"Job"} color={Colors.SECONDARY} selected={value == "Job"} handleClick={() => this.saveValue("Job")}/>
                             </ExtraInfo>
-                        </div>
+                        </DIV>
                     </StyledAccordionDetails>
                 </StyledAccordion>
-            </div>
-        )
+            </DIV>
+        );
     }
 
     private handleMetadataChange = () => { this.forceUpdate() }
