@@ -6,16 +6,19 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../../Global';
+import { DIV, Global } from '../../../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 import { Slider } from '../../../core';
 import { OptumiMetadataTracker } from '../../../models/OptumiMetadataTracker';
 import { StorageConfig } from '../../../models/StorageConfig';
 import { User } from '../../../models/User';
 import FormatUtils from '../../../utils/FormatUtils';
+import { Colors } from '../../../Colors';
 
 interface IProps {
-    style?: React.CSSProperties,
+    sx?: SxProps<Theme>,
 }
 
 interface IState {}
@@ -74,7 +77,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var user: User = Global.user;
         return (
-            <div style={this.props.style}>
+            <DIV sx={this.props.sx}>
                 <Slider
                     getValue={this.getSizeValue}
                     saveValue={this.saveSizeValue}
@@ -82,7 +85,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
                     step={1048576}
                     maxValue={user.machines.storageSizeMax}
                     label={'Size'}
-                    color={'#89858b'}
+                    color={Colors.DISK}
                     showUnit
                     styledUnit={FormatUtils.styleCapacityUnit()}
                     styledValue={FormatUtils.styleCapacityValue()}
@@ -94,7 +97,7 @@ export class StorageComponent extends React.Component<IProps, IState> {
                     minValue={-1}
                     maxValue={user.machines.storageIopsMax}
                     label={'IOPS'}
-                    color={'#89858b'}
+                    color={Colors.DISK}
                     showUnit
                 />
                 <Slider
@@ -104,13 +107,13 @@ export class StorageComponent extends React.Component<IProps, IState> {
                     step={1000000}
                     maxValue={user.machines.storageThroughputMax}
                     label={'Throughput'}
-                    color={'#89858b'}
+                    color={Colors.DISK}
                     showUnit
                     styledUnit={FormatUtils.styleThroughputUnit()}
                     styledValue={FormatUtils.styleThroughputValue()}
                     unstyledValue={FormatUtils.unstyleThroughputValue()}
                 />
-            </div>
+            </DIV>
         )
     }
 
