@@ -6,17 +6,18 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../../Global';
+import { DIV, Global } from '../../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Button, Divider, IconButton } from '@mui/material';
+import { GetApp as GetAppIcon, Delete as DeleteIcon } from '@mui/icons-material';
 
 import { ServerConnection } from '@jupyterlab/services';
 
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
 // import { ChangePasswordPopup } from './ChangePasswordPopup';
 import { CreditBucketCheckoutForm } from './CreditBucketCheckoutForm';
 import { Header, Switch, TextBox, TextBoxDropdown } from '../../core';
 import FormatUtils from '../../utils/FormatUtils';
-import { Button, Divider, IconButton } from '@material-ui/core';
-import GetAppIcon from '@material-ui/icons/GetApp';
 import DataConnectorBrowser, { DataConnectorMetadata } from '../deploy/dataConnectorBrowser/DataConnectorBrowser';
 import { AmazonS3ConnectorPopup } from '../deploy/AmazonS3ConnectorPopup';
 import { GoogleCloudStorageConnectorPopup } from '../deploy/GoogleCloudStorageConnectorPopup';
@@ -25,23 +26,22 @@ import { KaggleConnectorPopup } from '../deploy/KaggleConnectorPopup';
 import { WasabiConnectorPopup } from '../deploy/WasabiConnectorPopup';
 // import { PhoneTextBox } from '../../core/PhoneTextBox';
 import { AzureBlobStorageConnectorPopup } from '../deploy/AzureBlobStorageConnector';
-import DeleteIcon from '@material-ui/icons/Delete';
 import { FileMetadata } from '../deploy/fileBrowser/FileBrowser';
 import { FileTree } from '../FileTree';
-import moment from 'moment';
 import { BillingType } from '../../models/User';
-import { MeteredBillingCheckoutForm } from './MeteredBillingCheckoutForm';
+import { MeteredBilling } from './MeteredBilling';
+import FileServerUtils from '../../utils/FileServerUtils';
+
+import moment from 'moment';
 import { PhoneNumberFormat, PhoneNumberUtil } from 'google-libphonenumber';
+import { FreeTrial } from './Freetrial';
 
 // Properties from parent
-interface IProps {
+interface IAccountPreferencesSubMenuProps {
     phoneValidOnBlur?: (valid: boolean) => void
-	style?: CSSProperties
+	sx?: SxProps<Theme>
 }
 
-// Properties for this component
-interface IState {}
-
 const emUpSub = 'Upgrade subscription to unlock'
 
 const LABEL_WIDTH = '80px'
@@ -50,9 +50,9 @@ interface IAccountPreferencesSubMenuState {
     switchKey: number
 }
 
-export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountPreferencesSubMenuState> {
+export class AccountPreferencesSubMenu extends React.Component<IAccountPreferencesSubMenuProps, IAccountPreferencesSubMenuState> {
 
-    constructor(props: IProps) {
+    constructor(props: IAccountPreferencesSubMenuProps) {
         super(props);
         this.state = {
             // We need to increment this when the user changes his number so the switch will be enabled/disabled properly
@@ -70,22 +70,22 @@ export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountP
         const phoneUtil = PhoneNumberUtil.getInstance();
         return (
             <>
-                <div style={Object.assign({padding: '6px'}, this.props.style)}>
+                <DIV sx={Object.assign({padding: '6px'}, this.props.sx)}>
                     {/* <ResourceTextBox<string>
                         getValue={this.getNameValue}
                         label='Name'
                         editPressRequired
                     /> */}
-                    {/* <div style={{display: 'inline-flex', width: '100%'}}>
+                    {/* <DIV sx={{display: 'inline-flex', width: '100%'}}>
                         <TextBox<string>
-                            style={{flexGrow: 1}}
+                            sx={{flexGrow: 1}}
                             getValue={this.getPasswordValue}
                             saveValue={this.savePasswordValue}
                             label='Password'
                             labelWidth={LABEL_WIDTH}
                         />
-                        <ChangePasswordPopup style={{margin: '8px 0px', height: '20px', fontSize: '12px', lineHeight: '12px'}}/>
-                    </div> */}
+                        <ChangePasswordPopup sx={{margin: '8px 0px', height: '20px', fontSize: '12px', lineHeight: '12px'}}/>
+                    </DIV> */}
                     {/* <PhoneTextBox
                         getValue={() => Global.user.phoneNumber}
                         saveValue={(phoneNumber: string) => {
@@ -126,7 +126,7 @@ export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountP
                             variant="outlined"
                             color="primary"
                             startIcon={<GetAppIcon />}
-                            style={{width: '100%'}}
+                            sx={{width: '100%'}}
                             onClick={async () => {
                                 const data = [];
                                 for (let app of Global.user.appTracker.finishedJobsOrSessions) {
@@ -191,7 +191,7 @@ export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountP
                             Download all runs
                         </Button>
                     )}
-                </div>
+                </DIV>
             </>
         )
     }
@@ -207,7 +207,7 @@ export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountP
         return s;
     }
 
-    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountPreferencesSubMenuProps, nextState: IAccountPreferencesSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -219,16 +219,22 @@ export class AccountPreferencesSubMenu extends React.Component<IProps, IAccountP
     }
 }
 
+// Properties from parent
+interface IAccountLimitsSubMenuProps {
+    // phoneValidOnBlur?: (valid: boolean) => void
+	sx?: SxProps<Theme>
+}
+
 interface IAccountLimitsSubMenuState {
     holdoverFocused: boolean;
     budgetFocused: boolean;
     recsFocused: boolean;
 }
 
-export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimitsSubMenuState> {
+export class AccountLimitsSubMenu extends React.Component<IAccountLimitsSubMenuProps, IAccountLimitsSubMenuState> {
     private _isMounted = false
 
-    constructor(props: IProps) {
+    constructor(props: IAccountLimitsSubMenuProps) {
         super(props);
         this.state = {
             holdoverFocused: false,
@@ -250,60 +256,58 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
 
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
-        return (
-            <>
-                <div style={Object.assign({padding: '6px'}, this.props.style)}>
-                    {Global.user.userExpertise > 0 ? (<TextBox<number>
-                        getValue={this.getUserBudgetValue}
-                        saveValue={this.saveUserBudgetValue}
-                        styledUnitValue={(value: number) => '$' + value.toFixed(2)}
-                        unstyleUnitValue={(value: string) => { return value.replace('$', '').replace('.', '').replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value.replace('$', '')) }}
-                        label='Budget'
-                        labelWidth={LABEL_WIDTH}
-                        onFocus={() => this.safeSetState({budgetFocused: true})}
-                        onBlur={() => this.safeSetState({budgetFocused: false})}
-                        helperText={this.state.budgetFocused ? `Must be between $1 and $${Global.user.maxBudget}` : 'Max monthly spend'}
-                        minValue={1}
-                        maxValue={Global.user.maxBudget}
-                        // disabledMessage={Global.user.userExpertise < 2 ? emUpSub : ''}
-                    />) : (<></>)}
-                    <TextBox<number>
-                        getValue={this.getMaxJobsValue}
-                        saveValue={this.saveMaxJobsValue}
-                        unstyleUnitValue={(value: string) => { return value.replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value) }}
-                        label='Jobs/Sessions'
-                        labelWidth={LABEL_WIDTH}
-                        helperText={'Max combined number of concurrent jobs and sessions'}
-                        disabledMessage={emUpSub}
-                    />
-                    <TextBox<number>
-                        getValue={this.getMaxMachinesValue}
-                        saveValue={this.saveMaxMachinesValue}
-                        unstyleUnitValue={(value: string) => { return value.replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value) }}
-                        label='Machines'
-                        labelWidth={LABEL_WIDTH}
-                        helperText='Max number of concurrent machines'
-                        disabledMessage={emUpSub}
-                    />
-                    <TextBoxDropdown
-                        getValue={this.getUserHoldoverTimeValue}
-                        saveValue={this.saveUserHoldoverTimeValue}
-                        unitValues={[
-                            {unit: 'seconds', value: 1},
-                            {unit: 'minutes', value: 60},
-                            {unit: 'hours', value: 3600},
-                        ]}
-                        label='Auto-release'
-                        labelWidth={LABEL_WIDTH}
-                        onFocus={() => this.safeSetState({holdoverFocused: true})}
-                        onBlur={() => this.safeSetState({holdoverFocused: false})}
-                        helperText={this.state.holdoverFocused ? `Must be between 0 seconds and ${Global.user.maxHoldoverTime / 3600} hours` : 'Time before releasing idle machines'}
-                        minValue={0}
-                        maxValue={Global.user.maxHoldoverTime}
-                    />
-                </div>
-            </>
-        )
+        return <>
+            <DIV sx={Object.assign({padding: '6px'}, this.props.sx)}>
+                {Global.user.userExpertise > 0 ? (<TextBox<number>
+                    getValue={this.getUserBudgetValue}
+                    saveValue={this.saveUserBudgetValue}
+                    styledUnitValue={(value: number) => '$' + value.toFixed(2)}
+                    unstyleUnitValue={(value: string) => { return value.replace('$', '').replace('.', '').replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value.replace('$', '')); }}
+                    label='Budget'
+                    labelWidth={LABEL_WIDTH}
+                    onFocus={() => this.safeSetState({budgetFocused: true})}
+                    onBlur={() => this.safeSetState({budgetFocused: false})}
+                    helperText={this.state.budgetFocused ? `Must be between $1 and $${Global.user.maxBudget}` : 'Max monthly spend'}
+                    minValue={1}
+                    maxValue={Global.user.maxBudget}
+                    // disabledMessage={Global.user.userExpertise < 2 ? emUpSub : ''}
+                />) : (<></>)}
+                <TextBox<number>
+                    getValue={this.getMaxJobsValue}
+                    saveValue={this.saveMaxJobsValue}
+                    unstyleUnitValue={(value: string) => { return value.replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value); }}
+                    label='Jobs/Sessions'
+                    labelWidth={LABEL_WIDTH}
+                    helperText={'Max combined number of concurrent jobs and sessions'}
+                    disabledMessage={emUpSub}
+                />
+                <TextBox<number>
+                    getValue={this.getMaxMachinesValue}
+                    saveValue={this.saveMaxMachinesValue}
+                    unstyleUnitValue={(value: string) => { return value.replace(/\d/g, '').length > 0 ? Number.NaN : Number.parseFloat(value); }}
+                    label='Machines'
+                    labelWidth={LABEL_WIDTH}
+                    helperText='Max number of concurrent machines'
+                    disabledMessage={emUpSub}
+                />
+                <TextBoxDropdown
+                    getValue={this.getUserHoldoverTimeValue}
+                    saveValue={this.saveUserHoldoverTimeValue}
+                    unitValues={[
+                        {unit: 'seconds', value: 1},
+                        {unit: 'minutes', value: 60},
+                        {unit: 'hours', value: 3600},
+                    ]}
+                    label='Auto-release'
+                    labelWidth={LABEL_WIDTH}
+                    onFocus={() => this.safeSetState({holdoverFocused: true})}
+                    onBlur={() => this.safeSetState({holdoverFocused: false})}
+                    helperText={this.state.holdoverFocused ? `Must be between 0 seconds and ${Global.user.maxHoldoverTime / 3600} hours` : 'Time before releasing idle machines'}
+                    minValue={0}
+                    maxValue={Global.user.maxHoldoverTime}
+                />
+            </DIV>
+        </>;
     }
 
     public componentDidMount = () => {
@@ -336,7 +340,7 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
 		}
 	}
 
-    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountLimitsSubMenuProps, nextState: IAccountLimitsSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -348,98 +352,79 @@ export class AccountLimitsSubMenu extends React.Component<IProps, IAccountLimits
     }
 }
 
-interface IAccountPaymentSubMenuState {
-    balance: number;
-    billing: any[];
+// Properties from parent
+interface IAccountBillingSubMenuProps {
+	sx?: SxProps<Theme>
+    balance: number
+    machineCost: number
+    serviceFeeCost: number
+    storageCost: number
+    egressCost: number
 }
 
-export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPaymentSubMenuState> {
+interface IAccountBillingSubMenuState {
+    balance: number
+}
+
+export class AccountBillingSubMenu extends React.Component<IAccountBillingSubMenuProps, IAccountBillingSubMenuState> {
     private _isMounted = false;
     private polling = false;
+    private timeout: NodeJS.Timeout
 
-    constructor(props: IProps) {
+    constructor(props: IAccountBillingSubMenuProps) {
         super(props);
         this.state = {
             balance: 0,
-            billing: [],
         }
     }
 
-    private getDuration = (record: any): string => {
-        var endTime = new Date(record.endTime as string);
-        var startTime = new Date(record.startTime as string);
-        var diff = endTime.getTime() - startTime.getTime();
-        const stillRunning = diff < 0;
-        if (stillRunning) {
-            diff = new Date().getTime() - startTime.getTime();
-        }
-        var time = FormatUtils.msToTime(diff).split(':');
-        var formatted;
-        if (time.length == 3) {
-            formatted = time[0] + 'h ' + time[1] + 'm ' + time[2] + 's';
-        } else {
-            formatted = time[0] + 'm ' + time[1] + 's';
-        }
-        return stillRunning ? formatted + ' (still running)' : formatted;
-    }
-
-    private getCost = (record: any): string => {
-        var endTime = new Date(record.endTime as string);
-        var startTime = new Date(record.startTime as string);
-        var diff = endTime.getTime() - startTime.getTime();
-        const stillRunning = diff < 0;
-        if (stillRunning) {
-            diff = new Date().getTime() - startTime.getTime();
-        }
-        var formatted = '$' + ((diff / 3600000) * record.machine.rate).toFixed(2);
-        return stillRunning ? formatted + ' (still running)' : formatted;
-    }
-
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
-                <div style={Object.assign({padding: '6px'}, this.props.style)}>
+                <DIV sx={Object.assign({padding: '6px'}, this.props.sx)}>
                     {Global.user.billingType == BillingType.CREDIT_BUCKET ? (
                         <>
-                            <div style={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
-                                <div 
-                                    style={{
+                            <DIV sx={{display: 'inline-flex', width: '100%', padding: '3px 0px'}}>
+                                <DIV 
+                                    sx={{
                                     lineHeight: '24px',
                                     margin: '0px 12px',
                                     flexGrow: 1,
                                 }}
                                 >
-                                    {'Remaining balance:'}
-                                </div>
-                                <div style={{padding: '0px 6px 0px 6px'}}>
+                                    {'Remaining balance'}
+                                </DIV>
+                                <DIV sx={{padding: '0px 6px 0px 6px'}}>
                                     {'$' + (-this.state.balance).toFixed(2)}
-                                </div>
-                            </div>
-                            <CreditBucketCheckoutForm />
+                                </DIV>
+                            </DIV>
+                            <DIV sx={{width: '250px'}}>
+                                <CreditBucketCheckoutForm />
+                            </DIV>
                         </>
                     ) : (
-                        <MeteredBillingCheckoutForm />
+                        <>
+                            {Global.user.subscriptionActive ? (
+                                <MeteredBilling 
+                                    machineCost={this.props.machineCost}
+                                    serviceFeeCost={this.props.serviceFeeCost}
+                                    storageCost={this.props.storageCost}
+                                    egressCost={this.props.egressCost}
+                                />
+                            ) : (
+                                <FreeTrial balance={this.props.balance}/>
+                            )}
+                        </>
                     )}
-                    <div style={{padding: '6px', width: '100%'}}>
-                        <Button
-                            variant="outlined"
-                            color="primary"
-                            startIcon={<GetAppIcon />}
-                            style={{width: '100%'}}
-                            onClick={() => this.getDetailedBilling(true)}
-                        >
-                            Billing records
-                        </Button>
-                    </div>
-                </div>
+                </DIV>
             </>
         )
     }
 
     private async receiveUpdate() {
 		const settings = ServerConnection.makeSettings();
-        const url = settings.baseUrl + "optumi/get-total-billing";
+        const url = settings.baseUrl + "optumi/get-balance";
         const now = new Date();
         const epoch = new Date(0);
 		const init: RequestInit = {
@@ -457,7 +442,7 @@ export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPayme
 			if (this.polling) {
 				// If we are polling, send a new request in 2 seconds
                 if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-				setTimeout(() => this.receiveUpdate(), 2000);
+				this.timeout = setTimeout(() => this.receiveUpdate(), 2000);
 			}
 			Global.handleResponse(response);
 			return response.json();
@@ -468,77 +453,9 @@ export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPayme
         });
     }
     
-    private getDetailedBilling = (save: boolean) => {
-        const settings = ServerConnection.makeSettings();
-        const url = settings.baseUrl + "optumi/get-detailed-billing";
-        const now = new Date();
-        const epoch = new Date(0);
-		const init: RequestInit = {
-			method: 'POST',
-			body: JSON.stringify({
-				startTime: epoch.toISOString(),
-				endTime: now.toISOString(),
-			}),
-		};
-		ServerConnection.makeRequest(
-			url,
-			init, 
-			settings
-		).then((response: Response) => {
-			Global.handleResponse(response);
-			return response.json();
-		}).then((body: any) => {
-			if (body) {
-                this.safeSetState({ billing: body.records });
-                if (save) {
-                    const data: string[][] = [];
-                    var sorted: any[] = body.records.sort((n1: any, n2: any) => {
-                        if (n1.startTime > n2.startTime) {
-                            return -1;
-                        }
-                        if (n1.startTime < n2.startTime) {
-                            return 1;
-                        }
-                        return 0;
-                    });
-                    for (let record of sorted) {
-                        const machine = record.machine;
-                        data.push(
-                            [
-                                new Date(record.startTime).toLocaleString().replace(/,/g, ''),
-                                new Date(0).toISOString() == new Date(record.endTime).toISOString() ? 'Still running' : new Date(record.endTime).toLocaleString().replace(/,/g, ''),
-                                this.getDuration(record),
-                                '$' + machine.rate.toFixed(2),
-                                this.getCost(record),
-                                machine.graphicsNumCards > 0 ? (machine.graphicsNumCards + 'x' + machine.graphicsCardType) : 'No GPU',
-                                machine.computeCores + ' cores',
-                                FormatUtils.styleCapacityUnitValue()(machine.memorySize),
-                                FormatUtils.styleCapacityUnitValue()(machine.storageSize)
-                            ]
-                        );
-                    }
-
-                    const headers = [
-                        ["Start Time", "End Time", "Duration", "Rate ($/hr)", "Cost", "GPU", "CPU", "RAM", "Disk"]
-                    ];
-                    
-                    var link = document.createElement("a");
-                    var blob = new Blob([headers.map(e => e.join(",")).join("\n") + '\n' + data.map(e => e.join(",")).join("\n") + '\n'], {
-                        type: "data:text/csv;charset=utf-8,"
-                    });
-                    link.setAttribute("href", window.URL.createObjectURL(blob));
-                    link.setAttribute("download", "billing_records.csv");
-                    document.body.appendChild(link); // Required for FF
-                    link.click();
-                }
-			}
-        });
-    }
-
     // Will be called automatically when the component is mounted
 	public componentDidMount = () => {
         this._isMounted = true;
-        this.getDetailedBilling(false);
         this.polling = true;
         this.receiveUpdate();
 	}
@@ -547,6 +464,7 @@ export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPayme
 	public componentWillUnmount = () => {
         this._isMounted = false;
         this.polling = false;
+        if (this.timeout != null) clearTimeout(this.timeout)
     }
     
     private safeSetState = (map: any) => {
@@ -571,7 +489,7 @@ export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPayme
 		}
 	}
 
-    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountBillingSubMenuProps, nextState: IAccountBillingSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -583,15 +501,20 @@ export class AccountPaymentSubMenu extends React.Component<IProps, IAccountPayme
     }
 }
 
+// Properties from parent
+interface IAccountConnectorsSubMenuProps {
+	sx?: SxProps<Theme>
+}
+
 interface IAccountConnectorsSubMenuState {
     dataConnectors: DataConnectorMetadata[],
     browserKey: number,
 }
 
-export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountConnectorsSubMenuState> {
+export class AccountConnectorsSubMenu extends React.Component<IAccountConnectorsSubMenuProps, IAccountConnectorsSubMenuState> {
     private _isMounted = false
 
-    constructor(props: IProps) {
+    constructor(props: IAccountConnectorsSubMenuProps) {
         super(props);
         this.state = {
             dataConnectors: [],
@@ -617,14 +540,14 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
             <>
-                <div style={Object.assign({}, this.props.style)}>
-                    <div style={{display: 'inline-flex', margin: '6px'}}>
-                        <Header title='Existing Connectors' style={{ lineHeight: '24px', margin: '6px 6px 6px 11px' }} />
-                    </div>
+                <DIV sx={Object.assign({}, this.props.sx)}>
+                    <DIV sx={{display: 'inline-flex', margin: '6px'}}>
+                        <Header title='Existing connectors' sx={{ lineHeight: '24px', margin: '6px 6px 6px 11px' }} />
+                    </DIV>
                     <Divider />
                     <DataConnectorBrowser
                         key={this.state.browserKey}
-                        style={{
+                        sx={{
                             maxHeight: 'calc(100% - 60px - 2px)',
                         }}
                         handleDelete={(dataConnectorMetadata: DataConnectorMetadata) => {
@@ -650,19 +573,19 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
                             }).then(() => Global.dataConnectorChange.emit(void 0));                   
                         }}
                     />
-                    <Divider style={{marginTop: '33px'}}/>
-                    <div style={{display: 'inline-flex', margin: '6px'}}>
-                        <Header title='New Connectors' style={{ lineHeight: '24px', margin: '6px 6px 6px 11px'  }} />
-                    </div>
+                    <Divider sx={{marginTop: '33px'}}/>
+                    <DIV sx={{display: 'inline-flex', margin: '6px'}}>
+                        <Header title='New connectors' sx={{ lineHeight: '24px', margin: '6px 6px 6px 11px'  }} />
+                    </DIV>
                     <Divider />
-                    <div style={{marginBottom: '6px'}} />
+                    <DIV sx={{marginBottom: '6px'}} />
                     <AmazonS3ConnectorPopup onClose={this.forceNewBrowser} />
                     <AzureBlobStorageConnectorPopup onClose={this.forceNewBrowser} />
                     <GoogleCloudStorageConnectorPopup onClose={this.forceNewBrowser} />
                     <GoogleDriveConnectorPopup onClose={this.forceNewBrowser} />
                     <KaggleConnectorPopup onClose={this.forceNewBrowser} />
                     <WasabiConnectorPopup onClose={this.forceNewBrowser} />
-                </div>
+                </DIV>
             </>
         )
     }
@@ -698,7 +621,7 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
 		}
 	}
 
-    public shouldComponentUpdate = (nextProps: IProps, nextState: IAccountConnectorsSubMenuState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountConnectorsSubMenuProps, nextState: IAccountConnectorsSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -710,10 +633,15 @@ export class AccountConnectorsSubMenu extends React.Component<IProps, IAccountCo
     }
 }
 
+// Properties from parent
+interface IAccountFilesSubMenuProps {
+	sx?: SxProps<Theme>
+}
+
 interface IAccountFilesSubMenuState {}
 
-export class AccountFilesSubMenu extends React.Component<IProps, IAccountFilesSubMenuState> {
-    constructor(props: IProps) {
+export class AccountFilesSubMenu extends React.Component<IAccountFilesSubMenuProps, IAccountFilesSubMenuState> {
+    constructor(props: IAccountFilesSubMenuProps) {
         super(props);
         this.state = {
             files: [],
@@ -725,94 +653,73 @@ export class AccountFilesSubMenu extends React.Component<IProps, IAccountFilesSu
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const files = Global.user.fileTracker.files;
-        return (
-            <>
-                <div style={Object.assign({padding: '20px 6px 6px 20px'}, this.props.style)}>
-                    <div>
-                        Listed files are securely stored in the Optumi platform. If you want to delete a file click on the associated trash can.
-                        {this.getTotalUsedStorage() > 0 && <>
-                            <br />
-                            <br />
-                            Total used storage: {this.formatSize(this.getTotalUsedStorage())}
-                        </>}
-                    </div>
-                    <FileTree<FileMetadata>
-                        files={files}
-                        fileTitle={file => (
+        var sorted: FileMetadata[] = !files ? [] : files.sort(FileServerUtils.sortFiles);
+        const total = Global.user.fileTracker.total
+        return <>
+            <DIV sx={Object.assign({padding: '20px 6px 6px 20px'}, this.props.sx)}>
+                <DIV>
+                    Listed files are securely stored in the Optumi platform. If you want to delete a file click on the associated trash can.
+                    {total > 0 && <>
+                        <br />
+                        <br />
+                        Total used storage: {FormatUtils.styleCapacityUnitValue()(Global.user.fileTracker.total)}
+                    </>}
+                </DIV>
+                <FileTree
+                    files={sorted}
+                    fileTitle={file => (
 `Name: ${file.name}
-${file.size === null ? '' : `Size: ${this.formatSize(file.size)}
+${file.size === null ? '' : `Size: ${FormatUtils.styleCapacityUnitValue()(file.size)} (${file.size} bytes)
 `}${file.path === '' ? '' : `Path: ${file.path.replace(file.name, '').replace(/\/$/, '')}
 `}Modified: ${moment(file.last_modified).format('YYYY-MM-DD hh:mm:ss')}`
-                        )}
-                        fileHidableIcon={file => ({
-                            width: 72,
-                            height: 36,
-                            icon: (
-                                <>
-                                    <IconButton
-                                        onClick={() => this.downloadFile(file)}
-                                        style={{ width: '36px', height: '36px', padding: '3px' }}
-                                    >
-                                        <GetAppIcon style={{ width: '30px', height: '30px', padding: '3px' }} />
-                                    </IconButton>
-                                    <IconButton
-                                        onClick={() => this.deleteFile(file)}
-                                        style={{ width: '36px', height: '36px', padding: '3px' }}
-                                    >
-                                        <DeleteIcon style={{ width: '30px', height: '30px', padding: '3px' }} />
-                                    </IconButton>
-                                </>
-                            ),
-                        })}
-                        directoryHidableIcon={path => ({
-                            width: 72,
-                            height: 36,
-                            icon: (
-                                <>
-                                    <IconButton
-                                        onClick={() => this.downloadDirectory(path)}
-                                        style={{ width: '36px', height: '36px', padding: '3px' }}
-                                    >
-                                        <GetAppIcon style={{ width: '30px', height: '30px', padding: '3px' }} />
-                                    </IconButton>
-                                    <IconButton
-                                        onClick={() => this.deleteDirectory(path)}
-                                        style={{ width: '36px', height: '36px', padding: '3px' }}
-                                    >
-                                        <DeleteIcon style={{ width: '30px', height: '30px', padding: '3px' }} />
-                                    </IconButton>
-                                </>
-                            ),
-                        })}
-                    />
-                </div>
-            </>
-        )
-    }
-
-    private formatSize = (value: number) => {
-		if (value == 0) return "";
-		if (value < Math.pow(1024, 1)) {
-            return value.toFixed() + ' B';
-        } else if (value < Math.pow(1024, 2)) {
-            return (value / Math.pow(1024, 1)).toFixed(1) + ' KiB';
-        } else if (value < Math.pow(1024, 3)) {
-            return (value / Math.pow(1024, 2)).toFixed(1) + ' MiB';
-        } else if (value < Math.pow(1024, 4)) {
-            return (value / Math.pow(1024, 3)).toFixed(1) + ' GiB';
-        } else if (value < Math.pow(1024, 5)) {
-            return (value / Math.pow(1024, 4)).toFixed(1) + ' TiB';
-        } else {
-            return (value / Math.pow(1024, 5)).toFixed(1) + ' PiB';
-        }
-	}
-
-    private getTotalUsedStorage = (): number => {
-        let totalUsedStorage: number = 0
-        for (let file of Global.user.fileTracker.files) {
-            totalUsedStorage += file.size
-        }
-        return totalUsedStorage
+                    )}
+                    fileHidableIcon={file => ({
+                        width: 72,
+                        height: 36,
+                        icon: (
+                            <>
+                                <IconButton
+                                    size='large'
+                                    onClick={() => this.downloadFile(file)}
+                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
+                                >
+                                    <GetAppIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
+                                </IconButton>
+                                <IconButton
+                                    size='large'
+                                    onClick={() => this.deleteFile(file)}
+                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
+                                >
+                                    <DeleteIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
+                                </IconButton>
+                            </>
+                        ),
+                    })}
+                    directoryHidableIcon={path => ({
+                        width: 72,
+                        height: 36,
+                        icon: (
+                            <>
+                                <IconButton
+                                    size='large'
+                                    onClick={() => this.downloadDirectory(path)}
+                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
+                                >
+                                    <GetAppIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
+                                </IconButton>
+                                <IconButton
+                                    size='large'
+                                    onClick={() => this.deleteDirectory(path)}
+                                    sx={{ width: '36px', height: '36px', padding: '3px' }}
+                                >
+                                    <DeleteIcon sx={{ width: '30px', height: '30px', padding: '3px' }} />
+                                </IconButton>
+                            </>
+                        ),
+                    })}
+                />
+            </DIV>
+        </>;
     }
 
     private async deleteFile(file: FileMetadata) {
@@ -826,7 +733,7 @@ ${file.size === null ? '' : `Size: ${this.formatSize(file.size)}
     private async deleteDirectory(path: string) {
         let filesToDelete: FileMetadata[] = []
         for (let file of Global.user.fileTracker.files) {
-            if (file.path.startsWith(path)) {
+            if (file.path.startsWith('~/' + path)) {
                 filesToDelete.push(file)
             }
         }
@@ -836,26 +743,26 @@ ${file.size === null ? '' : `Size: ${this.formatSize(file.size)}
     private async downloadDirectory(path: string) {
         let filesToDownload: FileMetadata[] = []
         for (let file of Global.user.fileTracker.files) {
-            if (file.path.startsWith(path)) {
+            if (file.path.startsWith('~/' + path)) {
                 filesToDownload.push(file)
             }
         }
-        Global.user.fileTracker.downloadFiles(path, filesToDownload, false);
+        Global.user.fileTracker.downloadFiles(path, filesToDownload, false, [], path);
     }
 
     private handleFilesChange = () => this.forceUpdate();
 
     // Will be called automatically when the component is mounted
 	public componentDidMount = () => {
-        Global.user.fileTracker.getFilesChanged().connect(this.handleFilesChange);
+        if (Global.user != null) Global.user.fileTracker.getFilesChanged().connect(this.handleFilesChange);
 	}
 
 	// Will be called automatically when the component is unmounted
 	public componentWillUnmount = () => {
-        Global.user.fileTracker.getFilesChanged().disconnect(this.handleFilesChange);
+        if (Global.user != null) Global.user.fileTracker.getFilesChanged().disconnect(this.handleFilesChange);
     }
 
-    public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
+    public shouldComponentUpdate = (nextProps: IAccountFilesSubMenuProps, nextState: IAccountFilesSubMenuState): boolean => {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
@@ -866,7 +773,7 @@ ${file.size === null ? '' : `Size: ${this.formatSize(file.size)}
         }
     }
 }
-export class TeamSubMenu extends React.Component<IProps, IState> {
+export class TeamSubMenu extends React.Component<IAccountFilesSubMenuProps, IAccountFilesSubMenuState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
