@@ -5,23 +5,26 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Button, CircularProgress, Dialog, DialogContent, withStyles } from '@material-ui/core';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { ArrowBackIos } from '@material-ui/icons';
 import * as React from 'react'
-import { Global } from '../Global';
-import DialogTitle from '@material-ui/core/DialogTitle';
-import { ShadowedDivider } from './ShadowedDivider';
-import { TextBox } from './TextBox';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Button, CircularProgress, Dialog, DialogContent, DialogTitle } from '@mui/material';
+import { withStyles } from '@mui/styles';
+import { ArrowBackIos } from '@mui/icons-material';
 
 import { ServerConnection } from '@jupyterlab/services';
+import { NotebookPanel } from '@jupyterlab/notebook';
+
+import { ShadowedDivider } from './ShadowedDivider';
+import { TextBox } from './TextBox';
 import { DataConnectorIdentity } from '../components/deploy/DataConnectorIdentity'
 import { DataService } from '../components/deploy/dataConnectorBrowser/DataConnectorDirListingItemIcon';
-import { NotebookPanel } from '@jupyterlab/notebook';
 import { DataConnectorUploadConfig } from '../models/DataConnectorUploadConfig';
 import { OptumiMetadataTracker } from '../models/OptumiMetadataTracker';
 import { UploadConfig } from '../models/UploadConfig';
 import ExtraInfo from '../utils/ExtraInfo';
+import { Colors } from '../Colors';
 
 const StyledDialog = withStyles({
     paper: {
@@ -29,7 +32,6 @@ const StyledDialog = withStyles({
         // width: '100%',
         height: '80%',
         overflowY: 'visible',
-        backgroundColor: 'var(--jp-layout-color1)',
         maxWidth: 'inherit',
     },
 })(Dialog);
@@ -47,7 +49,7 @@ const StyledButton = withStyles({
 
 interface IProps {
     onClose?: () => any
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     dataService: DataService
     description: string
     header: string
@@ -107,7 +109,7 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
     }
 
     private handleCreate = (add?: boolean) => {
-        this.safeSetState({ waiting: true, addSpinning: false, createSpinning: false })
+        this.safeSetState({ errorMessage: '', waiting: true, addSpinning: false, createSpinning: false })
         if (add) {
             setTimeout(() => {
                 if (this.state.waiting) this.safeSetState({ addSpinning: true });
@@ -164,7 +166,7 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('CreateConnectorPopup (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({}, this.props.style)}>
+            <DIV sx={Object.assign({}, this.props.sx)}>
                 <DataConnectorIdentity
                     dataService={this.props.dataService}
                     description={this.props.description}
@@ -175,30 +177,25 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                     open={this.state.open}
                     scroll='paper'
                 >
-                    <DialogTitle
-                        disableTypography
-                        style={{
-                            display: 'inline-flex',
-                            backgroundColor: 'var(--jp-layout-color2)',
-                            height: '60px',
-                            padding: '6px',
-                            borderRadius: '4px',
-                        }}
-                    >
-                        <div style={{
+                    <DialogTitle sx={{
+                        display: 'inline-flex',
+                        height: '60px',
+                        padding: '6px',
+                    }}>
+                        <DIV sx={{
                             display: 'inline-flex',
                             flexGrow: 1,
                             marginLeft: '-6px', // this is to counteract the padding in CreateDataConnector so we can reuse it without messing with it
                         }}>
                             <DataConnectorIdentity
                                 dataService={this.props.dataService}
-                                style={{ zoom: 1.4 }}
+                                sx={{ zoom: 1.4 }}
                             />
-                        </div>
-                        <div>
+                        </DIV>
+                        <DIV>
                             <StyledButton
                                 disableElevation
-                                style={{ margin: '6px', height: '36px' }}
+                                sx={{ margin: '6px', height: '36px' }}
                                 variant='outlined'
                                 onClick={this.handleClose}
                                 disabled={this.state.waiting}
@@ -206,11 +203,11 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                             >
                                 Back
                             </StyledButton>
-                        </div>
-                        <div>
+                        </DIV>
+                        <DIV>
                             <Button
                                 disableElevation
-                                style={{ margin: '6px', height: '36px' }}
+                                sx={{ margin: '6px', height: '36px' }}
                                 variant='contained'
                                 color='primary'
                                 onClick={() => this.handleCreate(false)}
@@ -221,23 +218,23 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                             <ExtraInfo reminder='Create and add to your notebook' >
                                 <Button
                                     disableElevation
-                                    style={{ margin: '6px', height: '36px' }}
+                                    sx={{ margin: '6px', height: '36px' }}
                                     variant='contained'
                                     color='primary'
                                     onClick={() => this.handleCreate(true)}
                                     disabled={(!(Global.labShell.currentWidget instanceof NotebookPanel) && Global.tracker.currentWidget != null) || this.state.waiting}
                                 >
-                                    {this.state.waiting && this.state.addSpinning ? <CircularProgress size='1.75em' /> : 'Create + Add'}
+                                    {this.state.waiting && this.state.addSpinning ? <CircularProgress size='1.75em' /> : 'Create and add'}
                                 </Button>
                             </ExtraInfo>
-                        </div>
+                        </DIV>
                     </DialogTitle>
                     <ShadowedDivider />
-                    <DialogContent style={{ padding: '0px', display: 'flex' }}>
-                        <div style={{ padding: '12px', display: 'flex', flexDirection: 'column' }}>
-                            <div style={{ margin: '12px 18px 18px 18px' }}>
+                    <DialogContent sx={{ padding: '0px', display: 'flex' }}>
+                        <DIV sx={{ padding: '12px', display: 'flex', flexDirection: 'column' }}>
+                            <DIV sx={{ margin: '12px 18px 18px 18px' }}>
                                 {this.props.header + " Files from this connector will be accessible in your notebook's working directory."}
-                            </div>
+                            </DIV>
                             <TextBox<string>
                                 getValue={() => this.state.name}
                                 saveValue={(value: string) => this.safeSetState({ name: value })}
@@ -257,17 +254,17 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                             /> */}
                             {this.props.getContents(this.state.waiting)}
                             {this.state.errorMessage && (
-                                <div style={{
-                                    color: '#f48f8d',
+                                <DIV sx={{
+                                    color: Colors.ERROR,
                                     margin: '36px 12px',
                                     wordBreak: 'break-all',
                                     fontSize: '12px',
                                 }}>
                                     {this.state.errorMessage}
-                                </div>
+                                </DIV>
                             )}
-                            <div style={{flexGrow: 1}}/>
-                            <div style={{
+                            <DIV sx={{flexGrow: 1}}/>
+                            <DIV sx={{
                                 margin: '12px 18px',
                                 fontStyle: 'italic',
                                 fontSize: '14px',
@@ -276,12 +273,12 @@ export class BaseConnectorPopup extends React.Component<IProps, IState> {
                                 color: 'gray'
                             }}>
                                 *required fields
-                            </div>
-                        </div>
+                            </DIV>
+                        </DIV>
                     </DialogContent>
                 </StyledDialog>
-            </div>
-        )
+            </DIV>
+        );
     }
 
     private safeSetState = (map: any) => {
