@@ -6,11 +6,12 @@
 **/
 
 import * as React from 'react';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { Global } from '../Global';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     title: string
     align?: 'left' | 'center' | 'right'
     grey?: boolean
@@ -22,15 +23,15 @@ export class Header extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({
+            <DIV sx={Object.assign({
                 textAlign: this.props.align || 'left',
                 fontSize: '16px',
                 fontWeight: 'bold',
                 lineHeight: '18px',
                 margin: '6px'
-            }, this.props.style)}>
+            }, this.props.sx)}>
                 {this.props.title}
-            </div>
+            </DIV>
         )
     }
 }
@@ -39,16 +40,16 @@ export class SubHeader extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
 		if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({
+            <DIV sx={Object.assign({
                 textAlign: this.props.align || 'left',
                 fontSize: '14px',
                 fontWeight: 'bold',
                 lineHeight: '18px',
                 margin: '6px',
                 opacity: this.props.grey ? 0.5 : 1,
-            }, this.props.style)}>
+            }, this.props.sx)}>
                 {this.props.title}
-            </div>
+            </DIV>
         )
     }
 }
