@@ -6,16 +6,19 @@
 **/
 
 import * as React from 'react'
-import { Global } from '../Global';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+
 import * as rendermime from '@jupyterlab/rendermime';
 import { Mode, CodeMirrorEditor } from '@jupyterlab/codemirror';
-import marked from 'marked';
 import { defaultSanitizer } from '@jupyterlab/apputils';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
+
+import marked from 'marked';
 
 interface IProps {
     text: string
-    style?: CSSProperties
+    sx?: SxProps<Theme>
 }
 interface IState {}
 
@@ -30,7 +33,7 @@ export class Markdown extends React.Component<IProps, IState> {
         html = rendermime.replaceMath(html, parts['math']);
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({}, this.props.style)} dangerouslySetInnerHTML={{ __html: defaultSanitizer.sanitize(html) }} />
+            <DIV sx={Object.assign({}, this.props.sx)} dangerouslySetInnerHTML={{ __html: defaultSanitizer.sanitize(html) }} />
         )
     }
 }
@@ -99,4 +102,4 @@ function initializeMarked(): void {
  export function renderMarked(content: string): string {
     initializeMarked();
     return marked(content)
-  }
\ No newline at end of file
+  }
