@@ -6,15 +6,18 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import { CSSProperties } from '@material-ui/core/styles/withStyles';
+import { DIV, Global, SPAN } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+
+// import ExtraInfo from '../utils/ExtraInfo';
+
 import ReactPhoneInput from 'react-phone-input-2';
 import 'react-phone-input-2/lib/style.css';
-// import ExtraInfo from '../utils/ExtraInfo';
 import libphonenumber from 'google-libphonenumber';
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     label?: string
     labelWidth?: string
     getValue: () => string
@@ -98,11 +101,11 @@ export class PhoneTextBox extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div
-                style={Object.assign({display: 'inline-flex', width: '100%', padding: '6px 0px'}, this.props.style)}
+            <DIV
+                sx={Object.assign({display: 'inline-flex', width: '100%', padding: '6px 0px'}, this.props.sx)}
             >
                 {this.props.label && (
-                    <div style={{
+                    <DIV sx={{
                         display: 'flex',
                         position: 'relative',
                         minWidth: this.props.labelWidth || '68px',
@@ -112,13 +115,14 @@ export class PhoneTextBox extends React.Component<IProps, IState> {
                         lineHeight: '24px',
                         // textAlign: 'center',
                     }}>
-                        <span style={{display: 'inline', width: '100%', color: !(this.props.disabledMessage == undefined || this.props.disabledMessage == '') ? 'var(--jp-ui-font-color3)' : 'var(--jp-ui-font-color1)'}}>
+                        <SPAN sx={{display: 'inline', width: '100%', color: !(this.props.disabledMessage == undefined || this.props.disabledMessage == '') ? 'var(--jp-ui-font-color3)' : 'var(--jp-ui-font-color1)'}}>
                             {this.props.label}
-                        </span>
-                    </div>
+                        </SPAN>
+                    </DIV>
                 )}
                 {/* <ExtraInfo reminder={this.state.invalidTextMessage}> */}
                     <ReactPhoneInput
+                        disabled={this.props.disabled}
                         value={'+' + this.state.value}
                         country={'us'}
                         onChange={this.handleChange}
@@ -131,7 +135,7 @@ export class PhoneTextBox extends React.Component<IProps, IState> {
                         isValid={this.state.invalidTextMessage == ''}
                     />
                 {/* </ExtraInfo> */}
-            </div>
+            </DIV>
         )
     }
 
