@@ -6,8 +6,20 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import { Slider as OtherSlider, withStyles, darken, Paper, OutlinedInput, InputLabel, FormControl, lighten, InputAdornment } from '@material-ui/core';
+import { DIV, Global } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import {
+    Slider as OtherSlider,
+    darken,
+    Paper,
+    OutlinedInput,
+    InputLabel,
+    FormControl,
+    lighten,
+    InputAdornment,
+} from '@mui/material';
+import { withStyles } from '@mui/styles';
 
 interface IProps {
     minValue: number
@@ -15,7 +27,7 @@ interface IProps {
     getValue: () => number
     saveValue: (value: number) => void
     color: string
-    style?: React.CSSProperties
+    sx?: SxProps<Theme>
 
     // Labeling
     label?: string
@@ -194,7 +206,7 @@ export class Slider extends React.Component<IProps, IState> {
         var fromLeft = 100 * props.value / this.max;
         return (
             <>
-                <this.StyledValueLabel style={{
+                <this.StyledValueLabel sx={{
                     display: props.open && this.props.showUnit ? 'inline-block' : 'none',
                     left: fromLeft + '%',
                     transform: 'translate(-' + fromLeft + '%, -25%)',
@@ -332,13 +344,13 @@ export class Slider extends React.Component<IProps, IState> {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         var showValue: boolean = alwaysShowValue || this.state.hovered || this.state.typing || this.props.alwaysDisplayUnit;
         return this.max == 0 ? (<></>) : (
-            <div
-                style={Object.assign({display: 'inline-flex', width: '100%'}, this.props.style)}
+            <DIV
+                sx={Object.assign({display: 'inline-flex', width: '100%'}, this.props.sx)}
                 onMouseOver={this.startHover}
                 onMouseOut={this.stopHover}
             >
                 <this.StyledSlider
-                    style={{position: 'relative'}}
+                    sx={{position: 'relative'}}
                     onChange={this.handleChange}
                     onChangeCommitted={this.handleChangeCommitted}
                     min={0}
@@ -351,7 +363,7 @@ export class Slider extends React.Component<IProps, IState> {
                 />
                 <FormControl
                     variant='outlined'
-                    style={{maxWidth: this.props.labelWidth || '68px', minWidth: this.props.labelWidth || '68px', margin: '0px 6px', display: showValue ? 'block' : 'none'}}
+                    sx={{maxWidth: this.props.labelWidth || '68px', minWidth: this.props.labelWidth || '68px', margin: '0px 6px', display: showValue ? 'block' : 'none'}}
                 >
                     <this.StyledInputLabel>
                         {this.props.label}
@@ -364,10 +376,10 @@ export class Slider extends React.Component<IProps, IState> {
                         onFocus={this.startTyping}
                         onBlur={this.stopTyping}
                         onKeyDown={(event: React.KeyboardEvent) => { if (event.key == 'Enter' || event.key == 'Escape') this.textField.current.blur() }}
-                        endAdornment={<InputAdornment position="end" disableTypography style={{fontSize: '12px', margin: '0px', height: '12px', paddingTop: '3px'}}>{this.props.styledUnit(this.state.value)}</InputAdornment>}
+                        endAdornment={<InputAdornment position="end" disableTypography sx={{fontSize: '12px', margin: '0px', height: '12px', paddingTop: '3px'}}>{this.props.styledUnit(this.state.value)}</InputAdornment>}
                     />
                 </FormControl>
-                <div style={{
+                <DIV sx={{
                     minWidth: this.props.labelWidth || '68px',
                     lineHeight: '24px',
                     textAlign: 'center',
@@ -375,8 +387,8 @@ export class Slider extends React.Component<IProps, IState> {
                     display: !showValue ? 'block' : 'none'
                 }}>
                     {this.props.label}
-                </div>
-            </div>
+                </DIV>
+            </DIV>
         )
     }
 
