@@ -6,18 +6,17 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { Button, OutlinedInput, FormControl, InputLabel, InputAdornment, IconButton, FormHelperText } from '@material-ui/core';
-import CloseIcon from '@material-ui/icons/Close';
-import DoneIcon from '@material-ui/icons/Done';
-import VisibilityIcon from '@material-ui/icons/Visibility';
-import VisibilityOffIcon from '@material-ui/icons/VisibilityOff';
-import LockIcon from '@material-ui/icons/Lock';
+import { DIV, Global, SPAN } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { Button, OutlinedInput, FormControl, InputLabel, InputAdornment, IconButton, FormHelperText } from '@mui/material';
+import { withStyles } from '@mui/styles';
+import { Close as CloseIcon, Done as DoneIcon, Visibility as VisibilityIcon, VisibilityOff as VisibilityOffIcon, Lock as LockIcon } from '@mui/icons-material';
+
 import ExtraInfo from '../utils/ExtraInfo';
 
 interface IProps<T> {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     label?: string
     labelWidth?: string
     getValue: () => T
@@ -83,8 +82,10 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                 padding: '0px',
             },
             input: {
+                lineHeight: '14px',
                 fontSize: '12px',
                 padding: '3px 6px 3px 6px',
+                height: '1.1876em',
             },
             adornedEnd: {
                 paddingRight: '0px',
@@ -208,7 +209,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
         return (
             <Button
                 onClick={this.startEdit}
-                style={{
+                sx={{
                     display: render ? 'flex' : 'none',
                     width: '100%',
                     minWidth: '0px',
@@ -228,7 +229,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                     onClick={this.discardChanges}
                     variant="outlined"
                     color="primary"
-                    style={{
+                    sx={{
                         display: render ? 'flex' : 'none',
                         width: '50%',
                         minWidth: '0px',
@@ -238,13 +239,13 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                         borderRight: '0px',
                     }}
                 >
-                    <CloseIcon style={{width: '20px', height: '20px'}} />
+                    <CloseIcon sx={{width: '20px', height: '20px'}} />
                 </Button>
                 <Button
                     onClick={this.saveChanges}
                     variant="outlined"
                     color="primary"
-                    style={{
+                    sx={{
                         display: render ? 'flex' : 'none',
                         width: '50%',
                         minWidth: '0px',
@@ -253,7 +254,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                         borderBottomLeftRadius: '0px',
                     }}
                 >
-                    <DoneIcon style={{width: '20px', height: '20px'}} />
+                    <DoneIcon sx={{width: '20px', height: '20px'}} />
                 </Button>
             </>
         )
@@ -261,7 +262,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
 
     private renderLabelOverButton = (render: boolean): JSX.Element => {
         return (
-            <this.StyledInputLabel shrink={true} style={{display: render ? 'flex' : 'none', position: 'absolute'}}>
+            <this.StyledInputLabel shrink={true} sx={{display: render ? 'flex' : 'none', position: 'absolute'}}>
                 {this.props.label}
             </this.StyledInputLabel>
         )
@@ -269,9 +270,9 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
 
     private renderLabel = (render: boolean): JSX.Element => {
         return (
-            <span style={{display: render ? 'inline' : 'none', width: '100%', color: !(this.props.disabledMessage == undefined || this.props.disabledMessage == '') ? 'var(--jp-ui-font-color3)' : 'var(--jp-ui-font-color1)'}}>
+            <SPAN sx={{display: render ? 'inline' : 'none', width: '100%', color: !(this.props.disabledMessage == undefined || this.props.disabledMessage == '') ? 'var(--jp-ui-font-color3)' : 'var(--jp-ui-font-color1)'}}>
                 {this.props.label + (this.props.required ? '*' : '')}
-            </span>
+            </SPAN>
         )
     }
 
@@ -310,13 +311,13 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
             }
         }
         return (
-            <div
-                style={Object.assign({display: 'inline-flex', width: '100%', padding: '6px 0px'}, this.props.style)}
+            <DIV
+                sx={Object.assign({display: 'inline-flex', width: '100%', padding: '6px 0px'}, this.props.sx)}
                 onMouseOver={this.startHover}
                 onMouseOut={this.stopHover}
             >
                 {this.props.label && (
-                    <div style={{
+                    <DIV sx={{
                         display: 'flex',
                         position: 'relative',
                         minWidth: this.props.labelWidth || '68px',
@@ -331,15 +332,18 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                         {this.renderEditButton(showEditButton)}
                         {this.renderConfirmCancelButtons(showConfirmCancelButtons)}
                         {this.renderLabelOverButton(!showLabel)}
-                    </div>
+                    </DIV>
                 )}
                 <ExtraInfo reminder={this.state.invalidTextMessage}>
                     <FormControl
                         error={this.state.invalidTextMessage != ''}
                         variant='outlined'
-                        style={{width: '100%', margin: '2px 6px', height: this.props.multiline ? '' : (this.props.helperText ? '32px' : '20px')}}
+                        sx={{width: '100%', margin: '2px 6px', height: this.props.multiline ? '' : (this.props.helperText ? '32px' : '20px')}}
                     >
                         <this.StyledOutlinedInput
+                            size='small'
+                            notched={false}
+                            label=''
                             inputRef={this.textField}
                             value={this.state.textValue}
                             placeholder={this.props.placeholder}
@@ -364,26 +368,24 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                             endAdornment={
                                 (this.props.disabled || !(this.props.disabledMessage == undefined || this.props.disabledMessage == '')) ? (
                                     // <ExtraInfo reminder={this.props.disabledMessage}>
-                                        <InputAdornment position="end" style={{height: '20px', margin: '0px 3px 0px 0px'}}>
-                                            <IconButton
-                                                disabled
-                                                style={{padding: '3px 3px 3px 0px'}}
-                                            >
-                                                <LockIcon style={{width: '14px', height: '14px'}} />
+                                        <InputAdornment position="end" sx={{height: '20px', margin: '0px 3px 0px 0px'}}>
+                                            <IconButton  size='large' disabled sx={{padding: '3px 3px 3px 0px'}}>
+                                                <LockIcon sx={{width: '14px', height: '14px'}} />
                                             </IconButton>
                                         </InputAdornment>
                                     // </ExtraInfo>
                                 ) : this.props.password && (
                                     // <ExtraInfo reminder={this.state.hidePassword ? 'Show Password' : 'Hide Password'}>
-                                        <InputAdornment position="end" style={{height: '20px', margin: '0px 3px 0px 0px'}}>
+                                        <InputAdornment position="end" sx={{height: '20px', margin: '0px 3px 0px 0px'}}>
                                             <IconButton
+                                                size='large'
                                                 onClick={() => this.safeSetState({hidePassword: !this.state.hidePassword})}
-                                                style={{padding: '3px 3px 3px 0px'}}
+                                                sx={{padding: '3px 3px 3px 0px'}}
                                             >
                                                 {this.state.hidePassword ? (
-                                                    <VisibilityOffIcon style={{width: '14px', height: '14px'}} /> 
+                                                    <VisibilityOffIcon sx={{width: '14px', height: '14px'}} /> 
                                                 ) : (
-                                                    <VisibilityIcon style={{width: '14px', height: '14px'}} />
+                                                    <VisibilityIcon sx={{width: '14px', height: '14px'}} />
                                                 )}
                                             </IconButton>
                                         </InputAdornment>
@@ -392,7 +394,7 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                             }
                         />
                         {this.props.helperText && 
-                            <FormHelperText style={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap', display: 'inline-flex'}}>
+                            <FormHelperText sx={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap', display: 'inline-flex'}}>
                                 {this.props.helperText}
                                 {this.props.helperLink && (
                                     <a href={this.props.helperLink.link} target="_blank" style={{flexGrow: 1, textAlign: 'end', fontStyle: 'italic'}}>
@@ -403,8 +405,8 @@ export class TextBox<T> extends React.Component<IProps<T>, IState<T>> {
                         }
                     </FormControl>
                 </ExtraInfo>
-            </div>
-        )
+            </DIV>
+        );
     }
 
     public componentDidMount = () => {
