@@ -6,9 +6,12 @@
 **/
 
 import * as React from 'react';
-import { Global } from '../Global';
-import withStyles, { CSSProperties } from '@material-ui/core/styles/withStyles';
-import { OutlinedInput, FormControl, FormHelperText, MenuItem, Select } from '@material-ui/core';
+import { DIV, Global, StyledSelect } from '../Global';
+
+import { SxProps, Theme } from '@mui/system';
+import { OutlinedInput, FormControl, FormHelperText, MenuItem, SelectChangeEvent } from '@mui/material';
+import { withStyles } from '@mui/styles';
+
 import ExtraInfo from '../utils/ExtraInfo';
 
 const StyledMenuItem = withStyles({
@@ -23,6 +26,7 @@ const StyledOutlinedInput = withStyles({
     input: {
         fontSize: '12px',
         padding: '3px 6px 3px 6px',
+        height: '1.1876em',
     },
     adornedEnd: {
         paddingRight: '0px',
@@ -30,7 +34,7 @@ const StyledOutlinedInput = withStyles({
 }) (OutlinedInput);
 
 interface IProps {
-    style?: CSSProperties
+    sx?: SxProps<Theme>
     label: string
     labelWidth?: string
     getValue: () => number
@@ -54,7 +58,6 @@ export class TextBoxDropdown extends React.Component<IProps, IState> {
     private _isMounted = false
 
     textField: React.RefObject<HTMLInputElement>
-    StyledSelect: any
 
     constructor(props: IProps) {
         super(props);
@@ -65,19 +68,6 @@ export class TextBoxDropdown extends React.Component<IProps, IState> {
             value: value,
             errorMessage: '',
         }
-        this.StyledSelect = this.getStyledSelect();
-    }
-
-    private getStyledSelect = () => {
-        return withStyles({
-            root: {
-                fontSize: "var(--jp-ui-font-size1)",
-                width: '68px',
-            },
-            iconOutlined: {
-                right: '0px'
-            }
-        }) (Select)
     }
 
     private normalize(value: number): [string, number] {
@@ -144,7 +134,7 @@ export class TextBoxDropdown extends React.Component<IProps, IState> {
         this.saveChanges()
     }
 
-    private handleUnitChange = (event: React.ChangeEvent<{ value: unknown }>) => {
+    private handleUnitChange = (event: SelectChangeEvent<unknown>) => {
         const unit = event.target.value as string
         const value = this.state.value
         const denormalizedValue = this.denormalize(unit, value)
@@ -177,31 +167,33 @@ export class TextBoxDropdown extends React.Component<IProps, IState> {
     public render = (): JSX.Element => {
         if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         return (
-            <div style={Object.assign({
+            <DIV sx={Object.assign({
                 display: 'inline-flex',
                 width: '100%',
                 padding: '6px 0px',
                 textAlign: 'center',
                 justifyContent: 'center'
-            }, this.props.style)}>
-                <div style={{
+            }, this.props.sx)}>
+                <DIV sx={{
                     minWidth: this.props.labelWidth || '68px',
                     margin: '0px 12px',
                     lineHeight: '24px',
                 }}>
                     {this.props.label}
-                </div>
+                </DIV>
                 <ExtraInfo reminder={this.state.errorMessage}>
                     <FormControl
                         error={this.state.errorMessage != ''}
                         variant='outlined'
-                        style={{
+                        sx={{
                             width: '100%',
                             margin: '2px 3px 2px 6px',
                             height: this.props.helperText ? '32px' : '20px',
                         }}
                     >
                         <StyledOutlinedInput
+                            notched={false}
+                            label=''
                             inputRef={this.textField}
                             value={this.state.value}
                             placeholder={this.props.placeholder}
@@ -211,28 +203,27 @@ export class TextBoxDropdown extends React.Component<IProps, IState> {
                             onKeyDown={(event: React.KeyboardEvent) => { if (event.key == 'Enter' || event.key == 'Escape') this.textField.current.blur() }}
                         />
                         {this.props.helperText && 
-                            <FormHelperText style={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap'}}>
+                            <FormHelperText sx={{fontSize: '10px', lineHeight: '10px', margin: '4px 6px', whiteSpace: 'nowrap'}}>
                                 {this.props.helperText}
                             </FormHelperText>
                         }
                     </FormControl>
                 </ExtraInfo>
-                <this.StyledSelect
+                <StyledSelect
                     value={this.state.unit}
-                    variant='outlined'
                     onChange={this.handleUnitChange}
                     onBlur={this.handleUnitBlur}
-                    SelectDisplayProps={{style: {padding: '3px 20px 3px 6px'}}}
-                    MenuProps={{MenuListProps: {style: {paddingTop: '6px', paddingBottom: '6px'}}}}
-                    style={{margin: '2px 6px 2px 3px', height: '20px'}}
+                    SelectDisplayProps={{style: {padding: '3px 20px 3px 6px', minHeight: 'unset'}}}
+                    MenuProps={{MenuListProps: {style: {paddingTop: '6px', paddingBottom: '7px'}}}}
+                    sx={{margin: '2px 6px 2px 3px', height: '20px'}}
                 >
                     {this.props.unitValues.map(unitValue =>
                         <StyledMenuItem key={unitValue.unit} value={unitValue.unit}>
                             {unitValue.unit}
                         </StyledMenuItem>
                     )}
-                </this.StyledSelect>
-            </div>
+                </StyledSelect>
+            </DIV>
         )
     }
 
