@@ -5,11 +5,23 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Button, Checkbox, Dialog, DialogActions, DialogContent, DialogTitle, ListItemText, Theme, withStyles } from '@material-ui/core'
 import * as React from 'react'
+import { DIV, Global } from '../Global';
+
+import {
+    Button,
+    Checkbox,
+    Dialog,
+    DialogActions,
+    DialogContent,
+    DialogTitle,
+    ListItemText,
+    Theme,
+} from '@mui/material';
+import { withStyles } from '@mui/styles';
+
 import { Header } from './Header'
 import { ShadowedDivider } from './ShadowedDivider'
-import { Global } from '../Global';
 
 const StyledDialog = withStyles((theme: Theme) => ({
     root: {
@@ -87,27 +99,25 @@ export default class WarningPopup extends React.Component<IProps, IState> {
             >
                 {this.props.headerText &&
                     <DialogTitle
-                        disableTypography
-                        style={{
+                        sx={{
                             backgroundColor: 'var(--jp-layout-color2)',
                             height: '48px',
                             padding: '6px 30px',
-                        }}
-                    >
+                        }}>
                         <Header
                             title={this.props.headerText}
-                            style={{lineHeight: '24px'}}
+                            sx={{lineHeight: '24px'}}
                         />
                     </DialogTitle>
                 }
                 <ShadowedDivider />
-                <div style={{padding: '18px'}}>
+                <DIV sx={{padding: '18px'}}>
                     {this.props.bodyText &&
-                        <DialogContent style={{padding: '6px 18px', whiteSpace: 'pre-wrap'}}>
+                        <DialogContent sx={{padding: '6px 18px', whiteSpace: 'pre-wrap'}}>
                             {this.props.bodyText}
                         </DialogContent>
                     }
-                    <DialogActions style={{padding: '12px 6px 6px 6px'}}>
+                    <DialogActions sx={{padding: '12px 6px 6px 6px'}}>
                         {this.props.preventText &&
                             <>
                                 <Checkbox
@@ -117,7 +127,7 @@ export default class WarningPopup extends React.Component<IProps, IState> {
                                 <ListItemText
                                     disableTypography
                                     primary={this.props.preventText}
-                                    style={{marginLeft: '0px', fontSize: '14px'}}
+                                    sx={{marginLeft: '0px', fontSize: '14px'}}
                                 />
                             </>
                         }
@@ -127,23 +137,21 @@ export default class WarningPopup extends React.Component<IProps, IState> {
                                 onClick={() => {
                                     this.safeSetState({prevent: false})
                                     this.props.cancel.onCancel(this.state.prevent)
-                                }}
-                                color={'default'}
-                            >
+                                }}>
                                 {this.props.cancel.text}
                             </Button>
                         }
                         <this.ContinueButton
                             variant='contained'
                             onClick={() => this.props.continue.onContinue(this.state.prevent)}
-                            style={{marginLeft: '18px'}}
+                            sx={{marginLeft: '18px'}}
                         >
                             {this.props.continue.text}
                         </this.ContinueButton>
                     </DialogActions>
-                </div>
+                </DIV>
            </StyledDialog>
-        )
+        );
     }
 
     public componentDidMount = () => {
@@ -175,4 +183,4 @@ export default class WarningPopup extends React.Component<IProps, IState> {
 			}
 		}
 	}
-}
\ No newline at end of file
+}
