@@ -22,7 +22,7 @@ export class ComputeConfig {
     // TODO:JJ
 
     constructor(map: any = {}, user: User = null) {
-        this.expertise = map.expertise || Expertise.BASIC;
+        this.expertise = map.expertise || Expertise.COMPONENT;
         this.required = map.required || false;
         this.rating = map.rating || [-1, -1, -1];
         this.score = map.score || [-1, -1, -1];
