@@ -7,11 +7,18 @@
 
 import { Global } from '../Global';
 
+import { ServerConnection } from '@jupyterlab/services';
 import { ISignal, Signal } from '@lumino/signaling';
 
 import FileServerUtils from '../utils/FileServerUtils';
-import { ServerConnection } from '@jupyterlab/services';
 import { FileMetadata } from '../components/deploy/fileBrowser/FileBrowser';
+import { Snackbar } from './Snackbar';
+
+enum UploadStatus {
+    COMPLETED = -1,
+    STORAGE_LIMIT = -2,
+    UPLOAD_SIZE = -3
+}
 
 class FileProgress {
     public path: string
@@ -76,6 +83,8 @@ export class FileTracker {
 	private polling = false;
     private fileProgress: FileProgress[]
     private _files: FileMetadata[]
+    public total: number = 0
+    public limit: number = 0
 
 	constructor() {
 		this.polling = true;
@@ -138,6 +147,9 @@ export class FileTracker {
                 key: metadata.path + key,
 				paths: paths,
                 compress: Global.user.compressFilesEnabled,
+                storageTotal: this.total,
+                storageLimit: this.limit,
+                autoAddOnsEnabled: Global.user.autoAddOnsEnabled,
 			}),
 		};
         if (Global.user.compressFilesEnabled) this.fileProgress.push(new FileProgress(metadata.path, key, 'compression'));
@@ -196,10 +208,30 @@ export class FileTracker {
 		});
 	}
 
-    public downloadFiles = async (name: string, files: FileMetadata[], overwrite: boolean, savePaths: string[] = []) => {
-        // If there is an unsigned agreement, do not poll
-        if (Global.user != null && Global.user.unsignedAgreement) {
-            return;
+    public downloadFiles = async (name: string, files: FileMetadata[], overwrite: boolean, savePaths: string[] = [], directory: string = null) => {
+        var shortestPath = files[0].path;
+        for (let file of files) {
+            var newShortest = '';
+            for (let i = 0; i < Math.min(shortestPath.length, file.path.length); i++) {
+                if (file.path[i] != shortestPath[i]) break;
+                newShortest += shortestPath[i];
+            }
+            shortestPath = newShortest;
+        }
+        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+        if (files.length == 1) {
+            Global.snackbarEnqueue.emit(new Snackbar(
+                "Downloading " + shortestPath,
+                { variant: 'success', }
+            ));
+        } else {
+            while (!shortestPath.endsWith('/')) {
+                shortestPath = shortestPath.substring(0, shortestPath.length-1)
+            }
+            Global.snackbarEnqueue.emit(new Snackbar(
+                "Downloading " + files.length + ' files to ' + shortestPath,
+                { variant: 'success', }
+            ));
         }
 
         const addPaths = savePaths.length == 0;
@@ -230,6 +262,7 @@ export class FileTracker {
                 sizes: sizes,
                 hashes: hashes,
                 overwrite: overwrite,
+                directory: directory,
 			}),
 		};
         this.fileProgress.push(new FileProgress(name, key, 'download'));
@@ -294,6 +327,33 @@ export class FileTracker {
                         }
                         progress.progress = body[merged].progress;
                         progress.total = body[merged].total;
+                        if (progress.progress < -1) {
+                            // This means we failed, so set the file to disabled
+                            const metadata = Global.metadata.getMetadata();
+                            for (let file of metadata.config.upload.files) {
+                                if (file.path == path) {
+                                    file.enabled = false;
+                                    if (progress.progress == UploadStatus.STORAGE_LIMIT) {
+                                        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+                                        Global.snackbarEnqueue.emit(new Snackbar(
+                                            "Skipping upload of " + path + ", not enough storage capacity",
+                                            { variant: 'warning', }
+                                        ));
+                                    } else if (progress.progress == UploadStatus.UPLOAD_SIZE) {
+                                        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+                                        Global.snackbarEnqueue.emit(new Snackbar(
+                                            "Skipping upload of " + path + ", exceeds the maximum size",
+                                            { variant: 'warning', }
+                                        ));
+                                    } else {
+                                        console.error("Unhandled file error case " + progress.progress)
+                                    }
+                                }
+                            } 
+                            Global.metadata.setMetadata(metadata)
+                            
+                            changed = true;
+                        }
                         if (progress.isDone()) this.forget(progress);
                         changed = true;
                     }
@@ -437,14 +497,22 @@ export class FileTracker {
             return;
         }
 
+        if (Global.shouldLogOnEmit) console.log('SignalEmit (' + new Date().getSeconds() + ')');
+        Global.snackbarEnqueue.emit(new Snackbar(
+            "Deleting " + (files.length == 1 ? files[0].name : files.length + ' files'),
+            { variant: 'success', }
+        ));
+
         this._files.filter(file => !files.map(x => x.hash + x.path).includes(file.hash + file.path));
         this._filesChanged.emit();
 
         const hashes = []
         const paths = [];
+        const creationTimes = [];
         for (var metadata of files) {
             hashes.push(metadata.hash);
             paths.push(metadata.path);
+            creationTimes.push(metadata.created);
         }
 
 		const settings = ServerConnection.makeSettings();
@@ -454,6 +522,7 @@ export class FileTracker {
 			body: JSON.stringify({
 				hashes: hashes,
                 paths: paths,
+                creationTimes: creationTimes,
 			}),
 		};
         return ServerConnection.makeRequest(
@@ -466,15 +535,16 @@ export class FileTracker {
 		}).then(() => {
             // The delete request could have resulted in a file being disabled, 
             Global.metadata.refreshMetadata()
+            this.receiveUpdate(false);
         });
 	}
 
     private filesPollDelay = 30000;
-    private receiveUpdate = async () => {
+    private receiveUpdate = async (poll: boolean = true) => {
         if (!this.polling) return;
         // If there is an unsigned agreement, do not poll
-        if (Global.user != null && Global.user.unsignedAgreement) {
-            setTimeout(() => this.receiveUpdate(), this.filesPollDelay);
+        if (Global.user == null || Global.user.unsignedAgreement) {
+            setTimeout(() => this.receiveUpdate(), 2000);
             return;
         }
 
@@ -489,7 +559,7 @@ export class FileTracker {
 			settings
 		).then((response: Response) => {
             Global.handleResponse(response);
-			if (this.polling) {
+			if (poll && this.polling) {
 				// If we are polling, send a new request in 30 seconds
                 if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
 				setTimeout(() => this.receiveUpdate(), this.filesPollDelay);
@@ -498,10 +568,14 @@ export class FileTracker {
 		}).then((body: any) => {
 			if (body) {
                 let newFiles: FileMetadata[] = []
+                if (body.total) this.total = +body.total;
+                if (body.limit) this.limit = +body.limit;                
+
                 if (body.files) {
                     for (let i = 0; i < body.files.length; i++) {
                         if (body.files[i] != '') {
                             newFiles.push({
+                                created: body.filescrt[i],
                                 last_modified: body.filesmod[i],
                                 name: (body.files[i] as string).split('/').pop(),
                                 path: body.files[i],
@@ -557,7 +631,7 @@ export class FileTracker {
                 this._filesChanged.emit();
 			}
         }, (error: ServerConnection.ResponseError) => {
-            if (this.polling) {
+            if (poll && this.polling) {
 				// If we are polling, send a new request in 30 seconds
                 if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
 				setTimeout(() => this.receiveUpdate(), this.filesPollDelay);
