@@ -5,13 +5,23 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { ISignal, Signal } from '@lumino/signaling';
+import { Machine, NoMachine } from './machine/Machine';
 
-import { Machine } from './machine/Machine';
+import { ISignal, Signal } from '@lumino/signaling';
 
 export class Machines {
 	public inventory: Machine[];
 
+    private _machinesByName = new Map<string, Machine>()
+    public getMachine(name: string): Machine {
+        return this._machinesByName.get(name) || new NoMachine()
+    }
+
+    public cpuLabels: string[][]
+    public cpuGrid: Machine[][][]
+    public gpuLabels: string[][]
+    public gpuGrid: Machine[][][]
+
     private _changed = new Signal<this, Machines>(this);
 
 	get changed(): ISignal<this, Machines> {
@@ -75,8 +85,39 @@ export class Machines {
     // The most expensive machine available, incase we want to adjust the max resource cap in the future
     public mostExpensiveMachine: Machine = null;
 
-	constructor(machines: Machine[], maxCost: number) {
+	constructor(machines: Machine[], cpuLabels: string[][], cpuGrid: Machine[][][], gpuLabels: string[][], gpuGrid: Machine[][][], maxCost: number) {
         this.inventory = [...machines];
+        this.cpuLabels = [...cpuLabels];
+        this.cpuGrid = [...cpuGrid];
+        this.gpuLabels = [...gpuLabels];
+        this.gpuGrid = [...gpuGrid];
+
+        for (let row of cpuGrid) {
+            var bucketSize = 0;
+            for (let bucket of row) {
+                if (bucket.length > bucketSize) bucketSize = bucket.length;
+            }
+            for (let bucket of row) {
+                const thisBucketSize = bucket.length;
+                for (let i = 0; i < bucketSize - thisBucketSize; i++) {
+                    bucket.push(new NoMachine());
+                }
+            }
+        }
+
+        for (let row of gpuGrid) {
+            var bucketSize = 0;
+            for (let bucket of row) {
+                if (bucket.length > bucketSize) bucketSize = bucket.length;
+            }
+            for (let bucket of row) {
+                const thisBucketSize = bucket.length;
+                for (let i = 0; i < bucketSize - thisBucketSize; i++) {
+                    bucket.push(new NoMachine());
+                }
+            }
+        }
+
         this.setAbsoluteMaxResources(maxCost);
         // Global.onUserChange.connect(() => this.setAbsoluteMaxResources());
     }
@@ -98,6 +139,8 @@ export class Machines {
 
     public setAbsoluteMaxResources(maxCost: number) {
         for (let machine of this.inventory) {
+            this._machinesByName.set(machine.name, machine)
+
             if (machine.rate > maxCost) continue;
 
             if (machine.graphicsNumCards > 0) {
@@ -141,10 +184,10 @@ export class Machines {
                 if (!this.graphicsFrequency.includes(graphicsFrequency)) this.graphicsFrequency.push(graphicsFrequency);
             }
         
-            var computeCores: number = machine.computeCores;
+            var computeCores: number = machine.computeCores[1];
             if (!this.computeCores.includes(computeCores)) this.computeCores.push(computeCores);
 
-            var computeScore: number = machine.computeScore;
+            var computeScore: number = machine.computeScore[1];
             if (!this.computeScore.includes(computeScore)) this.computeScore.push(computeScore);
 
             var computeFrequency: number = machine.computeFrequency;
