@@ -6,14 +6,17 @@
 **/
 
 import { Global } from "../Global";
+
 import { v4 as uuid } from 'uuid';
 
 export class OptumiMetadata {
     public nbKey: string;
+    public nbKeyHistory: string[];
 	public version: string = Global.version;
 	
 	constructor(map: any = {}) {
         this.nbKey = map.nbKey || uuid();
+        this.nbKeyHistory = map.nbKeyHistory || [];
 		this.version = map.version || "None";
 		if (this.version.includes("DEV")) this.version = "DEV";
 	}
