@@ -6,18 +6,19 @@
 **/
 
 import { OptionsObject } from "notistack";
+import { Colors } from "../Colors";
 
 /// NOTE: Look here for possible props: https://iamhosseindhv.com/notistack/api#enqueuesnackbar-options
 
 export const providerOptions = {
-    success: { backgroundColor: '#7cdf8e!important' },
-    error: { backgroundColor: '#f48f8d!important' },
-    warning: { backgroundColor: '#ffba7d!important' },
-    info: { backgroundColor: '#10A0F9!important' },
+    success: { backgroundColor: Colors.SUCCESS + ' !important' },
+    error: { backgroundColor: Colors.ERROR + ' !important' },
+    warning: { backgroundColor: Colors.WARNING + ' !important' },
+    info: { backgroundColor: Colors.PRIMARY + ' !important' },
 }
 
 export class Snackbar {
-    message: String;
+    message: string;
     options: OptionsObject;
 
     private standardOptions: OptionsObject = {
@@ -27,7 +28,7 @@ export class Snackbar {
         },
     }
 
-    constructor(message: String, options: OptionsObject) {
+    constructor(message: string, options: OptionsObject) {
         this.message = message;
         this.options = Object.assign({}, options, this.standardOptions);
     }
