@@ -6,31 +6,27 @@
 **/
 
 import * as React from 'react'
+import { Global } from '../../Global';
+
+import { ServerConnection } from '@jupyterlab/services';
+import { NotebookModel } from '@jupyterlab/notebook';
+import { ISignal, Signal } from '@lumino/signaling';
 
 import { ProgressMessage } from '../ProgressMessage';
 import { Module, Status } from '../Module';
-
-import { ISignal, Signal } from '@lumino/signaling';
-
-import { ServerConnection } from '@jupyterlab/services';
-
 import { AppTracker } from './AppTracker';
 import { OptumiConfig } from '../OptumiConfig';
 import { FileUploadConfig } from '../FileUploadConfig';
 import { Machine, NoMachine } from '../machine/Machine';
-import { Global } from '../../Global';
-
 import { Update } from '../Update';
 import { Snackbar } from '../Snackbar';
 import FileServerUtils from '../../utils/FileServerUtils';
-
 import { IdentityAppComponent } from './IdentityAppComponent';
 import { AppComponent } from './AppComponent';
 import { PopupAppComponent } from './PopupAppComponent';
+import { FileMetadata } from '../../components/deploy/fileBrowser/FileBrowser';
 
 import { applyPatch } from 'rfc6902';
-import { NotebookModel } from '@jupyterlab/notebook';
-import { FileMetadata } from '../../components/deploy/fileBrowser/FileBrowser';
 
 export enum Phase {
 	Initializing = 'initializing',
@@ -132,7 +128,8 @@ export class App {
 			for (let i = 0; i < appMap.files.length; i++) {
 				if (appMap.files[i] != '') {
 					inputFiles.push({
-						last_modified: appMap.filesmod[i],
+						created: appMap.filescrt ? appMap.filescrt[i] : undefined, // Handle backwards compatibility from before we had creation time
+						last_modified: appMap.filesmod ? appMap.filesmod[i] : undefined,
 						name: (appMap.files[i] as string).split('/').pop(),
 						path: appMap.files[i],
 						size: +appMap.filessize[i],
@@ -163,7 +160,8 @@ export class App {
 				for (let i = 0; i < module.files.length; i++) {
 					if (module.files[i] != '') {
 						outputFiles.push({
-							last_modified: module.filesmod[i],
+							created: module.filescrt ? module.filescrt[i] : undefined, // Handle backwards compatibility from before we had creation time
+							last_modified: module.filesmod ? module.filesmod[i] : undefined,
 							name: (module.files[i] as string).split('/').pop(),
 							path: module.files[i],
 							size: +module.filessize[i],
@@ -203,7 +201,7 @@ export class App {
 				}
 			}
 
-			var mod: Module = new Module(module.uuid, module.machine ? Object.setPrototypeOf(module.machine, Machine.prototype) : null, module.token, output, updates, outputFiles, monitoring, lastPatch);
+			var mod: Module = new Module(module.uuid, module.machine ? Machine.parse(module.machine) : null, module.token, output, updates, outputFiles, monitoring, lastPatch);
 			mod.applyPatch = app.applyPatch;
 			app._modules.push(mod);
 		}
@@ -410,7 +408,7 @@ export class App {
 				console.log("//");
 
 				for (let machine of body.machines) {
-					console.log(Object.setPrototypeOf(machine, Machine.prototype));
+					console.log(Machine.parse(machine));
 				}
 
 				console.log("//");
@@ -420,7 +418,7 @@ export class App {
             if (body.machines.length == 0) return [new NoMachine()]; // we have no recommendations
             const machines: Machine[] = [];
             for (let machine of body.machines) {
-                machines.push(Object.setPrototypeOf(machine, Machine.prototype));
+                machines.push(Machine.parse(machine));
             }
 			return machines;
 		});
@@ -511,6 +509,7 @@ export class App {
 						for (let i = 0; i < body.files.length; i++) {
 							if (body.files[i] != '') {
 								this._files.push({
+									created: body.filescrt[i],
 									last_modified: body.filesmod[i],
 									name: (body.files[i] as string).split('/').pop(),
 									path: body.files[i],
@@ -633,9 +632,10 @@ export class App {
 		if (this.interactive && message == 'Running' && !(this.modules.length > 0 && this.modules[0].sessionReady)) return 'Connecting';
 		// We call a running app 'Connected'
 		if (this.interactive && message == 'Running') return 'Connected';
-		// We call a terminated app 'closed'
+		// We call a terminated or completed app 'closed',
 		if (this.interactive && message == 'Terminating') return 'Closing';
 		if (this.interactive && message == 'Terminated') return 'Closed';
+		if (this.interactive && message == 'Completed') return 'Closed';
 		return message;
 	}
 
