@@ -6,13 +6,14 @@
 **/
 
 import { App } from './App';
-import { Status } from '../Module';
-
-import { ISignal, Signal } from '@lumino/signaling';
 import { Global } from '../../Global';
 
 import { ServerConnection } from '@jupyterlab/services';
 
+import { Status } from '../Module';
+
+import { ISignal, Signal } from '@lumino/signaling';
+
 export class AppTracker {
 	private _polling = false;
 
@@ -23,12 +24,6 @@ export class AppTracker {
 		this._polling = true;
 		this.receiveAppUpdates();
 		this.receiveModuleUpdates();
-
-		for (var app of this.activeSessions) {
-			for (var module of app.modules) {
-				module.startSessionHandler();
-			}
-		}
 	}
 
 	get appsChanged(): ISignal<this, App[]> {
@@ -146,7 +141,7 @@ export class AppTracker {
 		} catch (err) {
 			console.error(err);
 			if (Global.shouldLogOnPoll) console.log('FunctionPoll (' + new Date().getSeconds() + ')');
-			setTimeout(() => this.receiveModuleUpdates(), this.modPollingDelay);
+			setTimeout(() => this.receiveAppUpdates(), this.modPollingDelay);
 		}
 	}
 	// If we are polling, send a new request 1 seconds after completing the previous request
@@ -230,13 +225,4 @@ export class AppTracker {
 			setTimeout(() => this.receiveModuleUpdates(), this.modPollingDelay);
 		}
 	}
-
-	public stopPolling() {
-		this._polling = false;
-		for (var app of this.activeSessions) {
-			for (var module of app.modules) {
-				module.stopSessionHandler();
-			}
-		}
-	}
 }
