@@ -5,10 +5,12 @@
 **  To receive a copy of the licensing terms please write to contact@optumi.com or visit us at http://www.optumi.com.
 **/
 
-import { Divider } from '@material-ui/core';
 import * as React from 'react';
+import { DIV, Global } from '../../Global';
+
+import { Divider } from '@mui/material';
+
 import { Header, Label } from '../../core';
-import { Global } from '../../Global';
 import FormatUtils from '../../utils/FormatUtils';
 import { Machine } from './Machine';
 
@@ -27,13 +29,13 @@ export class MachineCapability extends React.Component<IProps, IState> {
     }
 
     public render = (): JSX.Element => {
-        if (Global.shouldLogOnRender) console.log('MachineCapabilitiesRender (' + new Date().getSeconds() + ')');
+        if (Global.shouldLogOnRender) console.log('ComponentRender (' + new Date().getSeconds() + ')');
         const machine = this.props.machine;
         return (
             <>
                 {machine.graphicsNumCards > 0 && (
                     <>
-                        <div style={{ margin: '6px' }}>
+                        <DIV sx={{ margin: '6px' }}>
                             <Header title='GPU' align='left' />
                             {machine.graphicsCardType !== 'None' && <Label<string>
                                 align='left'
@@ -61,22 +63,22 @@ export class MachineCapability extends React.Component<IProps, IState> {
                                 label='Frequency'
                                 styledUnitValue={FormatUtils.styleFrequencyUnitValue()}
                             />}
-                        </div>
+                        </DIV>
                         <Divider variant='middle' />
                     </>
                 )}
-                {machine.computeCores > 0 && (
+                {machine.computeCores[1] > 0 && (
                     <>
-                        <div style={{ margin: '6px' }}>
+                        <DIV sx={{ margin: '6px' }}>
                             <Header title='CPU' align='left' />
-                            {machine.computeCores > 0 && <Label<number>
+                            {machine.computeCores[1] > 0 && <Label<number>
                                 align='left'
-                                getValue={() => machine.computeCores}
+                                getValue={() => machine.computeCores[1]}
                                 label='Cores'
                             />}
-                            {Global.user.userExpertise >= 2 && machine.computeScore > 0 && <Label<number>
+                            {Global.user.userExpertise >= 2 && machine.computeScore[1] > 0 && <Label<number>
                                 align='left'
-                                getValue={() => machine.computeScore}
+                                getValue={() => machine.computeScore[1]}
                                 label='Score'
                             />}
                             {Global.user.userExpertise >= 2 && machine.computeFrequency > 0 && <Label<number>
@@ -85,13 +87,13 @@ export class MachineCapability extends React.Component<IProps, IState> {
                                 label='Frequency'
                                 styledUnitValue={FormatUtils.styleFrequencyUnitValue()}
                             />}
-                        </div>
+                        </DIV>
                         <Divider variant='middle' />
                     </>
                 )}
                 {machine.memorySize > 0 && (
                     <>
-                        <div style={{ margin: '6px' }}>
+                        <DIV sx={{ margin: '6px' }}>
                             <Header title='RAM' align='left' />
                             {machine.memorySize > 0 && <Label<number>
                                 align='left'
@@ -99,13 +101,13 @@ export class MachineCapability extends React.Component<IProps, IState> {
                                 label='Size'
                                 styledUnitValue={FormatUtils.styleCapacityUnitValue()}
                             />}
-                        </div>
+                        </DIV>
                         <Divider variant='middle' />
                     </>
                 )}
                 {machine.storageSize > 0 && (
                     <>
-                        <div style={{ margin: '6px' }}>
+                        <DIV sx={{ margin: '6px' }}>
                             <Header title='DSK' align='left' />
                             {machine.storageSize > 0 && <Label<number>
                                 align='left'
@@ -124,7 +126,7 @@ export class MachineCapability extends React.Component<IProps, IState> {
                                 label='Throughput'
                                 styledUnitValue={FormatUtils.styleThroughputUnitValue()}
                             />}
-                        </div>
+                        </DIV>
                         <Divider variant='middle' />
                     </>
                 )}
@@ -136,7 +138,7 @@ export class MachineCapability extends React.Component<IProps, IState> {
         try {
             if (JSON.stringify(this.props) != JSON.stringify(nextProps)) return true;
             if (JSON.stringify(this.state) != JSON.stringify(nextState)) return true;
-            if (Global.shouldLogOnRender) console.log('SuppressedRender')
+            if (Global.shouldLogOnRender) console.log('SuppressedRender (' + new Date().getSeconds() + ')');
             return false;
         } catch (error) {
             return true;
