@@ -7,12 +7,15 @@
 
 import * as React from 'react';
 import { Global } from '../../Global';
+
+import { CircularProgress, IconButton } from '@mui/material';
+import { Delete as DeleteIcon } from '@mui/icons-material';
+
 import { ServerConnection } from '@jupyterlab/services';
+
 import { Machine } from './Machine';
 import { Tag } from '../../components/Tag';
 import { InfoSkirt } from '../../components/InfoSkirt';
-import { CircularProgress, IconButton } from '@material-ui/core';
-import DeleteIcon from '@material-ui/icons/Delete';
 import { User } from '../User';
 import WarningPopup from '../../core/WarningPopup';
 import FormatUtils from '../../utils/FormatUtils';
@@ -216,6 +219,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
                         />
                         <ExtraInfo reminder='Release'>
                             <IconButton
+                                size='large'
                                 onClick={() => {
                                     if (machine.app) {
                                         this.safeSetState({showDeleteMachinePopup: true})
@@ -226,10 +230,10 @@ export class MachineComponent extends React.Component<IProps, IState> {
                                     }
                                 }}
                                 disabled={this.state.deleting || this.state.waiting || this.props.machine.state.includes('sequestration')}
-                                style={{position: 'relative', display: 'inline-block', width: '36px', height: '36px', padding: '3px'}}
+                                sx={{position: 'relative', display: 'inline-block', width: '36px', height: '36px', padding: '3px'}}
                             >
-                                <DeleteIcon style={{position: 'relative', width: '30px', height: '30px', padding: '3px'}} />
-                                {(this.state.deleting || this.state.waiting) && this.state.spinning && <CircularProgress size='30px' style={{position: 'absolute'}} />}
+                                <DeleteIcon sx={{position: 'relative', width: '30px', height: '30px', padding: '3px'}} />
+                                {(this.state.deleting || this.state.waiting) && this.state.spinning && <CircularProgress size='30px' sx={{position: 'absolute', left: '3px', top: '3px'}} />}
                             </IconButton>
                         </ExtraInfo>
                     </>
@@ -238,7 +242,7 @@ export class MachineComponent extends React.Component<IProps, IState> {
             >
                 {this.props.machine.getIdentityComponent()}
             </InfoSkirt>
-        )
+        );
     }
 
     public shouldComponentUpdate = (nextProps: IProps, nextState: IState): boolean => {
