@@ -6,6 +6,11 @@
 **/
 
 export default class FormatUtils {
+    public static formatCredit = (balance: number) => {
+        if (balance > 0) return '$0.00'
+        return '$' + (-balance).toFixed(2)
+    }
+    
     public static msToTime(s: number) {
         var ms = s % 1000;
         s = (s - ms) / 1000;
@@ -21,13 +26,13 @@ export default class FormatUtils {
         return (value: number): string => {
             if (value == -1) return ''
             if (value < Math.pow(1024, 3)) {
-                return 'MiB';
+                return 'MB';
             } else if (value < Math.pow(1024, 4)) {
-                return 'GiB';
+                return 'GB';
             } else if (value < Math.pow(1024, 5)) {
-                return 'TiB';
+                return 'TB';
             } else {
-                return 'PiB';
+                return 'PB';
             }
         };
     }
@@ -51,13 +56,13 @@ export default class FormatUtils {
         return (value: number): string => {
             if (value == -1) return ''
             if (value < Math.pow(1024, 3)) {
-                return 'MiB';
+                return 'MB';
             } else if (value < Math.pow(1024, 4)) {
-                return 'GiB';
+                return 'GB';
             } else if (value < Math.pow(1024, 5)) {
-                return 'TiB';
+                return 'TB';
             } else {
-                return 'PiB';
+                return 'PB';
             }
         };
     }
@@ -68,11 +73,11 @@ export default class FormatUtils {
             if (value == -1) return 'unsp'
             if (unit) {
                 // We don't care about the size, use a specified unit
-                if (unit == 'MiB') {
+                if (unit == 'MB') {
                     ret = (value / Math.pow(1024, 2));
-                } else if (unit == 'GiB') {
+                } else if (unit == 'GB') {
                     ret = (value / Math.pow(1024, 3));
-                } else if (unit == 'TiB') {
+                } else if (unit == 'TB') {
                     ret = (value / Math.pow(1024, 4));
                 } else {
                     ret = (value / Math.pow(1024, 5));
@@ -97,6 +102,11 @@ export default class FormatUtils {
                     return ret.toFixed(1);
                 }
                 return ret.toFixed(2);
+            } else if (ret.toFixed(0).length == 2) {
+                if (ret.toFixed(1).endsWith('0')) {
+                    return ret.toFixed(0);
+                }
+                return ret.toFixed(1);
             }
             return ret.toFixed(0);
         };
@@ -108,16 +118,16 @@ export default class FormatUtils {
             if (isNaN(value)) return Number.NaN
             switch (unit.toLowerCase()) {
             case 'm':
-            case 'mib':
+            case 'mb':
                 return value * Math.pow(1024, 2)
             case 'g':
-            case 'gib':
+            case 'gb':
                 return value * Math.pow(1024, 3)
             case 't':
-            case 'tib':
+            case 'tb':
                 return value * Math.pow(1024, 4)
             case 'p':
-            case 'pib':
+            case 'pb':
                 return value * Math.pow(1024, 5)
             default:
                 return value
@@ -129,15 +139,15 @@ export default class FormatUtils {
         return (value: number): string => {
             if (value == -1) return 'unsp'
             if (value < Math.pow(1024, 2)) {
-                return FormatUtils.customPrecision(value / Math.pow(1024, 1)) + ' KiB';
+                return FormatUtils.customPrecision(value / Math.pow(1024, 1)) + ' KB';
             } else if (value < Math.pow(1024, 3)) {
-                return FormatUtils.customPrecision(value / Math.pow(1024, 2)) + ' MiB';
+                return FormatUtils.customPrecision(value / Math.pow(1024, 2)) + ' MB';
             } else if (value < Math.pow(1024, 4)) {
-                return FormatUtils.customPrecision(value / Math.pow(1024, 3)) + ' GiB';
+                return FormatUtils.customPrecision(value / Math.pow(1024, 3)) + ' GB';
             } else if (value < Math.pow(1024, 5)) {
-                return FormatUtils.customPrecision(value / Math.pow(1024, 4)) + ' TiB';
+                return FormatUtils.customPrecision(value / Math.pow(1024, 4)) + ' TB';
             } else {
-                return FormatUtils.customPrecision(value / Math.pow(1024, 5)) + ' PiB';
+                return FormatUtils.customPrecision(value / Math.pow(1024, 5)) + ' PB';
             }
         };
     }
@@ -155,13 +165,13 @@ export default class FormatUtils {
     //         if (isNaN(value)) return Number.NaN
     //         var unit: string = unitValue.replace(/[0-9\.]+/, '').trim()
     //         switch (unit.toLowerCase()) {
-    //         case 'mib':
+    //         case 'mb':
     //             return value * Math.pow(1024, 2)
-    //         case 'gib':
+    //         case 'gb':
     //             return value * Math.pow(1024, 3)
-    //         case 'tib':
+    //         case 'tb':
     //             return value * Math.pow(1024, 4)
-    //         case 'pib':
+    //         case 'pb':
     //             return value * Math.pow(1024, 5)
     //         default:
     //             return Number.NaN
@@ -179,7 +189,7 @@ export default class FormatUtils {
             } else if (value < Math.pow(1000, 5)) {
                 return 'TBps';
             } else {
-                return 'PiB';
+                return 'PBps';
             }
         };
     }
